@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -29,9 +29,6 @@
              (srfi srfi-1)
              (srfi srfi-26))
 
-(define %supported-systems
-  '("x86_64-linux" "i686-linux"))
-
 (define (final-inputs store system)
   "Return the list of outputs directories of the final inputs for SYSTEM."
   (append-map (match-lambda
