@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -70,7 +70,8 @@
                          #:optional (package-derivation package-derivation))
   "Convert PACKAGE to an alist suitable for Hydra."
   `((derivation . ,(derivation-file-name
-                    (package-derivation store package system)))
+                    (package-derivation store package system
+                                        #:graft? #f)))
     (description . ,(package-synopsis package))
     (long-description . ,(package-description package))
     (license . ,(package-license package))
@@ -93,7 +94,9 @@ SYSTEM."
   `(,(symbol-append (string->symbol target) (string->symbol ".") job-name
                     (string->symbol ".") (string->symbol system)) .
     ,(cute package->alist store package system
-           (cut package-cross-derivation <> <> target <>))))
+           (lambda* (store package system #:key graft?)
+             (package-cross-derivation store package target system
+                                       #:graft? graft?)))))
 
 (define %core-packages
   ;; Note: Don't put the '-final' package variants because (1) that's
@@ -144,14 +147,18 @@ system.")
   (if (member system '("x86_64-linux" "i686-linux"))
       (list (->job 'qemu-image
                    (run-with-store store
-                     (system-qemu-image (demo-os)
-                                        #:disk-image-size
-                                        (* 1400 MiB)))) ; 1.4 GiB
+                     (mbegin %store-monad
+                       (set-guile-for-build (default-guile))
+                       (system-qemu-image (demo-os)
+                                          #:disk-image-size
+                                          (* 1400 MiB))))) ; 1.4 GiB
             (->job 'usb-image
                    (run-with-store store
-                     (system-disk-image installation-os
-                                        #:disk-image-size
-                                        (* 800 MiB)))))
+                     (mbegin %store-monad
+                       (set-guile-for-build (default-guile))
+                       (system-disk-image installation-os
+                                          #:disk-image-size
+                                          (* 800 MiB))))))
       '()))
 
 (define job-name
