@@ -631,7 +631,10 @@ system administrator.")
                 "002l6h27pnhb77b65frhazbhknsxvrsnkpi43j7i0qw1lrgi7nkf"))))
     (build-system gnu-build-system)
     (arguments
-     `(#:configure-flags '("--with-logpath=/var/log/sudo.log")
+     `(#:configure-flags '("--with-logpath=/var/log/sudo.log"
+                           "--with-rundir=/run/sudo"
+                           "--with-vardir=/var/db/sudo"
+                           "--with-iologdir=/var/log/sudo-io")
        #:phases (alist-cons-before
                  'configure 'pre-configure
                  (lambda _
@@ -645,7 +648,13 @@ system administrator.")
                       "")
                      (("^install: (.*)install-sudoers(.*)" _ before after)
                       ;; Don't try to create /etc/sudoers.
-                      (string-append "install: " before after "\n"))))
+                      (string-append "install: " before after "\n"))
+                     (("\\$\\(DESTDIR\\)\\$\\(rundir\\)")
+                      ;; Don't try to create /run/sudo.
+                      "$(TMPDIR)/dummy")
+                     (("\\$\\(DESTDIR\\)\\$\\(vardir\\)")
+                      ;; Don't try to create /var/db/sudo.
+                      "$(TMPDIR)/dummy")))
                  %standard-phases)
 
        ;; XXX: The 'testsudoers' test series expects user 'root' to exist, but
@@ -689,9 +698,12 @@ commands and their arguments.")
                    (let ((port (open-file ".config" "al")))
                      (display "
       CONFIG_DEBUG_SYSLOG=y
-      CONFIG_CTRL_IFACE_DBUS=y
-      CONFIG_CTRL_IFACE_DBUS_NEW=y
-      CONFIG_CTRL_IFACE_DBUS_INTRO=y
+
+      # TODO: Add a variant of this package with DBus support.
+      #CONFIG_CTRL_IFACE_DBUS=y
+      #CONFIG_CTRL_IFACE_DBUS_NEW=y
+      #CONFIG_CTRL_IFACE_DBUS_INTRO=y
+
       CONFIG_DRIVER_NL80211=y
       CFLAGS += $(shell pkg-config libnl-3.0 --cflags)
       CONFIG_LIBNL32=y
@@ -708,7 +720,9 @@ commands and their arguments.")
     (inputs
      `(("readline" ,readline)
        ("libnl" ,libnl)
-       ("dbus" ,dbus)
+       ;; TODO: Add a variant with DBus support.  This significantly increases
+       ;; the size of its closure since DBus depends on libx11.
+       ;; ("dbus" ,dbus)
        ("openssl" ,o:openssl)))
     (native-inputs
      `(("pkg-config" ,pkg-config)))
