@@ -48,7 +48,7 @@
      '(#:parallel-build? #f
        #:parallel-tests? #f))
     (inputs `(("perl" ,perl)
-              ("libtool" ,libtool)))
+              ("libltdl" ,libltdl)))
     (home-page "http://apr.apache.org/")
     (synopsis "The Apache Portable Runtime Library")
     (description
@@ -64,14 +64,14 @@ around or take advantage of platform-specific deficiencies or features.")
 (define-public apr-util
   (package
     (name "apr-util")
-    (version "1.5.3")
+    (version "1.5.4")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://apache/apr/apr-util-"
                                  version ".tar.bz2"))
              (sha256
               (base32
-               "0s1rpqjy5xr03k9s4xrsm5wvhj5286vlkf6jvqayw99yy5sb3vbq"))))
+               "0bn81pfscy9yjvbmyx442svf43s6dhrdfcsnkpxz43fai5qk5kx6"))))
     (build-system gnu-build-system)
     (inputs
       `(("apr" ,apr)))
