@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
 ;;;
@@ -70,6 +70,26 @@ independent of the input data and can be reduced, if necessary, at some cost
 in compression.")
     (license license:zlib)))
 
+(define-public fastjar
+  (package
+   (name "fastjar")
+   (version "0.98")
+   (source (origin
+             (method url-fetch)
+             (uri (string-append "mirror://savannah/fastjar/fastjar-"
+                                 version ".tar.gz"))
+             (sha256
+              (base32
+               "0iginbz2m15hcsa3x4y7v3mhk54gr1r7m3ghx0pg4n46vv2snmpi"))))
+   (build-system gnu-build-system)
+   (inputs `(("zlib" ,zlib)))
+   (home-page "http://savannah.nongnu.org/projects/fastjar")
+   (synopsis "Replacement for Sun's 'jar' utility")
+   (description
+    "FastJar is an attempt to create a much faster replacement for Sun's 'jar'
+utility.  Instead of being written in Java, FastJar is written in C.")
+   (license license:gpl2+)))
+
 (define-public gzip
   (package
    (name "gzip")
@@ -95,13 +115,7 @@ file; as a result, it is often used in conjunction with \"tar\", resulting in
    (home-page "http://www.gnu.org/software/gzip/")))
 
 (define-public bzip2
-  (let ((fix-man-dir
-         ;; Move man pages to $out/share/.
-         '(lambda* (#:key outputs #:allow-other-keys)
-            (with-directory-excursion (assoc-ref outputs "out")
-              (mkdir "share")
-              (rename-file "man" "share/man"))))
-        (build-shared-lib
+  (let ((build-shared-lib
          ;; Build a shared library.
          '(lambda* (#:key inputs #:allow-other-keys)
             (patch-makefile-SHELL "Makefile-libbz2_so")
@@ -151,20 +165,16 @@ file; as a result, it is often used in conjunction with \"tar\", resulting in
               `(alist-cons-before
                 'build 'build-shared-lib ,build-shared-lib
                 (alist-cons-after
-                 'install 'fix-man-dir ,fix-man-dir
-                 (alist-cons-after
-                  'install 'install-shared-lib ,install-shared-lib
-                  (alist-replace 'configure ,set-cross-environment
-                                 %standard-phases))))
+                 'install 'install-shared-lib ,install-shared-lib
+                 (alist-replace 'configure ,set-cross-environment
+                                %standard-phases)))
 
               ;; Native compilation: build the shared library.
               `(alist-cons-before
                 'build 'build-shared-lib ,build-shared-lib
                 (alist-cons-after
-                 'install 'fix-man-dir ,fix-man-dir
-                 (alist-cons-after
-                  'install 'install-shared-lib ,install-shared-lib
-                  (alist-delete 'configure %standard-phases)))))
+                 'install 'install-shared-lib ,install-shared-lib
+                 (alist-delete 'configure %standard-phases))))
 
          #:make-flags (list (string-append "PREFIX="
                                            (assoc-ref %outputs "out")))
