@@ -22,8 +22,7 @@
   #:use-module (gnu packages gdbm)
   #:use-module (gnu packages mit-krb5)
   #:use-module (gnu packages openssl)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'license:))
+  #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix build-system gnu))
@@ -49,11 +48,17 @@
    (arguments
     '(#:configure-flags (list (string-append "--with-plugindir="
                                              (assoc-ref %outputs "out")
-                                             "/lib/sasl2"))))
-   (synopsis "Cyrus SASL, an implementation of the Simple Authentication Security Layer framework")
+                                             "/lib/sasl2"))
+
+      ;; The 'plugins' directory has shared source files, such as
+      ;; 'plugin_common.c'.  When building the shared libraries there, libtool
+      ;; ends up doing "ln -s plugin_common.lo plugin_common.o", which can
+      ;; fail with EEXIST when building things in parallel.
+      #:parallel-build? #f))
+   (synopsis "Simple Authentication Security Layer implementation")
    (description
     "SASL (Simple Authentication Security Layer) is an Internet
-standards-track method for remote computers to authenticate. The Cyrus SASL
+standards-track method for remote computers to authenticate.  The Cyrus SASL
 library makes supporting various SASL mechanisms easy for both client and
 server writers.")
    (license (license:bsd-style "file://COPYING"
