@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -62,18 +62,18 @@
          ("indent" ,indent))))
     (propagated-inputs `(("m4" ,m4)))
     (home-page "http://flex.sourceforge.net/")
-    (synopsis "A fast lexical analyser generator")
+    (synopsis "Fast lexical analyser generator")
     (description
-     "Flex is a tool for generating scanners. A scanner, sometimes
+     "Flex is a tool for generating scanners.  A scanner, sometimes
 called a tokenizer, is a program which recognizes lexical patterns in
-text. The flex program reads user-specified input files, or its standard
+text.  The flex program reads user-specified input files, or its standard
 input if no file names are given, for a description of a scanner to
-generate. The description is in the form of pairs of regular expressions
-and C code, called rules. Flex generates a C source file named,
-\"lex.yy.c\", which defines the function yylex(). The file \"lex.yy.c\"
-can be compiled and linked to produce an executable. When the executable
+generate.  The description is in the form of pairs of regular expressions
+and C code, called rules.  Flex generates a C source file named,
+\"lex.yy.c\", which defines the function yylex().  The file \"lex.yy.c\"
+can be compiled and linked to produce an executable.  When the executable
 is run, it analyzes its input for occurrences of text matching the
-regular expressions for each rule. Whenever it finds a match, it
+regular expressions for each rule.  Whenever it finds a match, it
 executes the corresponding C code.")
     (license (bsd-style "file://COPYING"
                         "See COPYING in the distribution."))))
