@@ -2,6 +2,7 @@
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2013 Joshua Grant <tadni@riseup.net>
 ;;; Copyright © 2014 David Thompson <davet@gnu.org>
+;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -19,6 +20,7 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages gl)
+  #:use-module (ice-9 match)
   #:use-module ((guix licenses) #:prefix l:)
   #:use-module (guix packages)
   #:use-module (guix download)
@@ -27,11 +29,14 @@
   #:use-module (gnu packages bison)
   #:use-module (gnu packages flex)
   #:use-module (gnu packages pkg-config)
+  #:use-module (gnu packages gettext)
+  #:use-module (gnu packages linux)
   #:use-module (gnu packages python)
   #:use-module (gnu packages xorg)
   #:use-module (gnu packages xml)
   #:use-module (gnu packages fontutils)
-  #:use-module (gnu packages guile))
+  #:use-module (gnu packages guile)
+  #:use-module (gnu packages xdisorg))
 
 (define-public glu
   (package
@@ -121,49 +126,68 @@ Polygon meshes, and Extruded polygon meshes")
 (define-public mesa
   (package
     (name "mesa")
-    ;; In newer versions (9.0.5, 9.1 and 9.2 tested), "make" results in an
-    ;; infinite configure loop, see
-    ;; https://bugs.freedesktop.org/show_bug.cgi?id=58812
-    (version "8.0.5")
+    (version "10.4.0")
     (source
       (origin
         (method url-fetch)
-        (uri (string-append
-               "ftp://ftp.freedesktop.org/pub/mesa/older-versions/8.x/"
-               version
-               "/MesaLib-" version
-               ".tar.bz2"))
+        (uri (string-append "ftp://ftp.freedesktop.org/pub/mesa/"
+                            version "/MesaLib-" version ".tar.bz2"))
         (sha256
-          (base32
-            "0pjs8x51c0i6mawgd4w03lxpyx5fnx7rc8plr8jfsscf9yiqs6si"))))
+         (base32
+          "069j4ck51hc70gryhw3z0rkyhhl0bnhbks4xg1wqqw56l7rxz9wq"))))
     (build-system gnu-build-system)
     (propagated-inputs
       `(("glproto" ,glproto)
-        ("libdrm" ,libdrm-2.4.33)
+        ("libdrm" ,libdrm)
         ("libx11" ,libx11)
         ("libxdamage" ,libxdamage)
         ("libxxf86vm" ,libxxf86vm)))
     (inputs
-      `(("dri2proto" ,dri2proto)
+      `(("udev" ,eudev)
+        ("dri2proto" ,dri2proto)
+        ("dri3proto" ,dri3proto)
+        ("presentproto" ,presentproto)
+        ("libxshmfence" ,libxshmfence)
         ("expat" ,expat)
         ("libxfixes" ,libxfixes)
         ("libxml2" ,libxml2)
+        ;; TODO: Add 'libva'
+        ;; TODO: Add 'libxml2-python' for OpenGL ES 1.1 and 2.0 support
         ("makedepend" ,makedepend)))
     (native-inputs
       `(("pkg-config" ,pkg-config)
+        ("gettext" ,gnu-gettext)
         ("flex" ,flex)
         ("bison" ,bison)
         ("python" ,python-2))) ; incompatible with Python 3 (print syntax)
     (arguments
-      `(#:configure-flags
-         `("--with-gallium-drivers=r600,svga,swrast") ; drop r300 from the default list as it requires llvm
-        #:phases
-         (alist-cons-after
-          'unpack 'remove-symlink
-          (lambda _
-            ;; remove dangling symlink to /usr/include/wine/windows
-            (delete-file "src/gallium/state_trackers/d3d1x/w32api"))
-         %standard-phases)))
+     `(#:configure-flags
+       '(;; drop r300 from default gallium drivers, as it requires llvm
+         "--with-gallium-drivers=r600,svga,swrast"
+         "--enable-xa"
+
+         ;; on non-intel systems, drop i915 and i965
+         ;; from the default dri drivers
+         ,@(match (%current-system)
+             ((or "x86_64-linux" "i686-linux")
+              '())
+             (_
+              '("--with-dri-drivers=nouveau,r200,radeon,swrast"))))
+       #:phases (alist-cons-after
+                 'unpack 'add-missing-m4-files
+                 (lambda _
+                   ;; When these files are missing, make tries to rebuild
+                   ;; several parts of the build system.
+                   (zero? (system* "touch" "--date=@0"
+                                   "m4/libtool.m4" "m4/ltoptions.m4"
+                                   "m4/ltsugar.m4" "m4/ltversion.m4"
+                                   "m4/lt~obsolete.m4")))
+                 (alist-cons-after
+                  'unpack 'patch-create_test_cases
+                  (lambda _
+                    (substitute* "src/glsl/tests/lower_jumps/create_test_cases.py"
+                      (("/usr/bin/env bash") (which "bash"))))
+                  %standard-phases))))
     (home-page "http://mesa3d.org/")
     (synopsis "OpenGL implementation")
     (description "Mesa is a free implementation of the OpenGL specification -
@@ -172,6 +196,50 @@ allows Mesa to be used in many different environments ranging from software
 emulation to complete hardware acceleration for modern GPUs.")
     (license l:x11)))
 
+(define-public glew
+  (package
+    (name "glew")
+    (version "1.11.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append
+                    "mirror://sourceforge/glew/glew-"
+                    version
+                    ".tgz"))
+              (sha256
+               (base32
+                "1mhkllxz49l1x680dmzrv2i82qjrq017sykah3xc90f2d8qcxfv9"))
+              (modules '((guix build utils)))
+              (snippet
+               '(substitute* "config/Makefile.linux"
+                  (("= cc") "= gcc")
+                  (("/lib64") "/lib")))))
+    (build-system gnu-build-system)
+    (arguments
+     '(#:phases (alist-delete 'configure %standard-phases)
+       #:make-flags (list (string-append "GLEW_PREFIX="
+                                         (assoc-ref %outputs "out"))
+                          (string-append "GLEW_DEST="
+                                         (assoc-ref %outputs "out")))
+       #:tests? #f))                              ;no 'check' target
+    (inputs
+     `(("libxi" ,libxi)
+       ("libxmu" ,libxmu)
+       ("libx11" ,libx11)
+       ("mesa" ,mesa)))
+
+    ;; <GL/glew.h> includes <GL/glu.h>.
+    (propagated-inputs `(("glu" ,glu)))
+
+    (home-page "http://glew.sourceforge.net/")
+    (synopsis "OpenGL extension loading library for C and C++")
+    (description
+     "The OpenGL Extension Wrangler Library (GLEW) is a C/C++ extension
+loading library.  GLEW provides efficient run-time mechanisms for determining
+which OpenGL extensions are supported on the target platform.  OpenGL core and
+extension functionality is exposed in a single header file.")
+    (license l:bsd-3)))
+
 (define-public guile-opengl
   (package
     (name "guile-opengl")
