@@ -1,8 +1,9 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
-;;; Copyright © 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2015 Andreas Enge <andreas@enge.fr>
+;;; Copyright © 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2014 Ian Denhardt <ian@zenhack.net>
 ;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
+;;; Copyright © 2014, 2015 Federico Beffa <beffa@fbengineering.ch>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -46,7 +47,9 @@
   #:use-module (gnu packages xml)
   #:use-module (gnu packages gl)
   #:use-module (gnu packages compression)
-  #:use-module (gnu packages xorg))
+  #:use-module (gnu packages xorg)
+  #:use-module (gnu packages xdisorg)
+  #:use-module (gnu packages ncurses))
 
 (define-public brasero
   (package
@@ -141,17 +144,6 @@ The gnome-about program helps find which version of GNOME is installed.")
        (base32
         "19n4x25ndzngaciiyd8dd6s2mf9gv6nv3wv27ggns2smm7zkj1nb"))))
     (build-system gnu-build-system)
-    (arguments
-     `(#:phases
-       (alist-cons-before
-        'check 'pre-check
-        (lambda* (#:key inputs #:allow-other-keys #:rest args)
-          ;; This is needed, because without it, xmlint etc tries
-          ;; to download docbookx.dtd from the net
-          (setenv "XML_CATALOG_FILES" 
-                  (string-append (assoc-ref inputs "docbook-xml") 
-                                 "/xml/dtd/docbook/catalog.xml")))
-        %standard-phases)))
     (native-inputs
      `(("intltool" ,intltool)
        ("docbook-xml" ,docbook-xml-4.4)
@@ -218,19 +210,7 @@ and keep up to date translations of documentation.")
        ;; FIXME: Tests fail with:
        ;;   ImportError: No module named gi.repository
        ;; Where should that module come from?
-       #:tests? #f
-
-       #:phases (alist-cons-after
-                 'install 'set-mime-search-path
-                 (lambda* (#:key inputs outputs #:allow-other-keys)
-                   ;; Wrap 'evince' so that it knows where MIME info is.
-                   (let ((out  (assoc-ref outputs "out"))
-                         (mime (assoc-ref inputs "shared-mime-info")))
-                     (wrap-program (string-append out "/bin/evince")
-                                   `("XDG_DATA_DIRS" ":" prefix
-                                     ,(list (string-append mime "/share")
-                                            (string-append out "/share"))))))
-                 %standard-phases)))
+       #:tests? #f))
     (inputs
      `(("libspectre" ,libspectre)
        ;; ("djvulibre" ,djvulibre)
@@ -249,7 +229,9 @@ and keep up to date translations of documentation.")
        ("libsm" ,libsm)
        ("libice" ,libice)
        ("shared-mime-info" ,shared-mime-info)
-
+       ("dconf" ,dconf)
+       ("libcanberra" ,libcanberra)
+       
        ;; For tests.
        ("dogtail" ,python2-dogtail)))
     (native-inputs
@@ -310,6 +292,18 @@ for settings shared by various components of the GNOME desktop.")
     (inputs
      `(("perl" ,perl)
        ("perl-xml-simple" ,perl-xml-simple)))
+    (arguments
+     '(#:phases
+       (alist-cons-after
+        'install 'set-load-paths
+        ;; Tell 'icon-name-mapping' where XML::Simple is.
+        (lambda* (#:key outputs #:allow-other-keys)
+          (let* ((out  (assoc-ref outputs "out"))
+                 (prog (string-append out "/libexec/icon-name-mapping")))
+            (wrap-program
+             prog
+             `("PERL5LIB" = ,(list (getenv "PERL5LIB"))))))
+        %standard-phases)))
     (home-page "http://tango.freedesktop.org/Standard_Icon_Naming_Specification")
     (synopsis
      "Utility to implement the Freedesktop Icon Naming Specification")
@@ -434,7 +428,7 @@ some form of information without getting in the user's way.")
 (define-public libpeas
   (package
     (name "libpeas")
-    (version "1.9.0")
+    (version "1.12.1")
     (source
      (origin
       (method url-fetch)
@@ -443,7 +437,7 @@ some form of information without getting in the user's way.")
                           name "-" version ".tar.xz"))
       (sha256
        (base32
-        "13fzyzv6c0cfdj83z1s16lv8k997wpnzyzr0wfwcfkcmvz64g1q0"))))
+        "1mjjjjwphc83bjznmbsm7x0jg7ql261nys6qnl7mi0nkr4qvw476"))))
     (build-system gnu-build-system)
     (inputs
      `(("atk" ,atk)
@@ -456,6 +450,13 @@ some form of information without getting in the user's way.")
        ("glib:bin" ,glib "bin")
        ("gobject-introspection" ,gobject-introspection)
        ("intltool" ,intltool)))
+    (arguments
+     `(#:phases 
+       (alist-cons-before
+        'build 'pre-build
+        (lambda* _
+          (setenv "CC" "gcc"))
+        %standard-phases)))
     (home-page "https://wiki.gnome.org/Libpeas")
     (synopsis "GObject plugin system")
     (description
@@ -464,7 +465,6 @@ every application the chance to assume its own extensibility.  It also has a
 set of features including, but not limited to: multiple extension points; on
 demand (lazy) programming language support for C, Python and JS; simplicity of
 the API")
-
     (license license:lgpl2.0+)))
 
 (define-public gtkglext
@@ -482,6 +482,7 @@ the API")
     (build-system gnu-build-system)
     (inputs `(("gtk+" ,gtk+-2)
               ("mesa" ,mesa)
+              ("glu" ,glu)
               ("libx11" ,libx11)
               ("libxt" ,libxt)))
     (native-inputs `(("pkg-config" ,pkg-config)
@@ -586,7 +587,7 @@ dealing with different structured file formats.")
 (define-public librsvg
   (package
     (name "librsvg")
-    (version "2.40.2")
+    (version "2.40.6")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnome/sources/" name "/"
@@ -594,7 +595,7 @@ dealing with different structured file formats.")
                                   name "-" version ".tar.xz"))
               (sha256
                (base32
-                "071959yjb2i1bja7ciy4bmpnd6fn2is9jjqsvvvnsqwl69j9n128"))))
+                "01jgb11779080b80k2ncrhdphgillqrrnszal6vh8yv787r4kwwa"))))
     (build-system gnu-build-system)
     (arguments
      `(#:phases
@@ -606,7 +607,7 @@ dealing with different structured file formats.")
             ;; gdk-pixbuf's prefix.  Work around that.
             (("gdk_pixbuf_moduledir = .*$")
              (string-append "gdk_pixbuf_moduledir = "
-                            "$(prefix)/lib/gdk-pixbuf-2.0/2.0.10/"
+                            "$(prefix)/lib/gdk-pixbuf-2.0/2.10.0/"
                              "loaders\n"))
             ;; Likewise, create a separate 'loaders.cache' file.
             (("gdk_pixbuf_cache_file = .*$")
@@ -616,7 +617,7 @@ dealing with different structured file formats.")
          (lambda* (#:key inputs outputs #:allow-other-keys)
            (let ((loaders-directory 
                   (string-append (assoc-ref outputs "out")
-                                 "/lib/gdk-pixbuf-2.0/2.0.10/loaders")))
+                                 "/lib/gdk-pixbuf-2.0/2.10.0/loaders")))
              (zero?
               (system 
                (string-append 
@@ -625,7 +626,11 @@ dealing with different structured file formats.")
                 (string-join (find-files (assoc-ref inputs "gdk-pixbuf") 
                                          "libpixbufloader-.*\\.so") " ")
                 "> " loaders-directory ".cache")))))
-         %standard-phases))))
+         (alist-cons-before
+          'build 'pre-build
+          (lambda* _
+            (setenv "CC" "gcc"))
+          %standard-phases)))))
     (native-inputs
      `(("pkg-config" ,pkg-config)
        ("glib" ,glib "bin")                               ; glib-mkenums, etc.
@@ -1017,6 +1022,8 @@ widgets built in the loading process.")
     (license license:gpl2+))) ; This is correct.  GPL not LGPL
 
 (define-public libgnomeprint
+  ;; This library has been deprecated since 2006; see
+  ;; <https://mail.gnome.org/archives/devel-announce-list/2006-August/msg00005.html>.
   (package
     (name "libgnomeprint")
     (version "2.8.2")
@@ -1040,11 +1047,14 @@ widgets built in the loading process.")
        ("pkg-config" ,pkg-config)))
     (home-page "https://projects.gnome.org/gnome-print/home/faq.html")
     (synopsis "Printing framework for GNOME")
-    (description "Gnome-print is a high-quality printing framework for GNOME.")
+    (description
+     "GNOME-print was a printing framework for GNOME.  It has been deprecated
+since ca. 2006, when GTK+ itself incorporated printing support.")
     (license license:lgpl2.0+)))
 
 
 (define-public libgnomeprintui
+  ;; Deprecated; see libgnomeprint.
   (package
     (name "libgnomeprintui")
     (version "2.8.2")
@@ -1069,10 +1079,9 @@ widgets built in the loading process.")
        ("pkg-config" ,pkg-config)))
     (home-page "https://projects.gnome.org/gnome-print/home/faq.html")
     (synopsis "Printing framework for GNOME")
-    (description  "Gnome-print is a high-quality printing framework for GNOME.")
+    (description (package-description libgnomeprint))
     (license license:lgpl2.0+)))
 
-
 (define-public libbonoboui
   (package
     (name "libbonoboui")
@@ -1119,6 +1128,51 @@ widgets built in the loading process.")
 controls using the Bonobo component framework.")
     (license license:lgpl2.0+)))
 
+(define-public libwnck
+  (package
+    (name "libwnck")
+    (version "3.14.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version) "/"
+                                  name "-" version ".tar.xz"))
+              (sha256
+               (base32 "074jww04z8g9r1acndqap79wx4kbm3rpkf4lcg1v82b66iv0027m"))))
+    (build-system gnu-build-system)
+    (native-inputs
+     `(("pkg-config" ,pkg-config)
+       ("intltool" ,intltool)))
+    (propagated-inputs
+     `(("gtk+" ,gtk+)
+       ("libxres" ,libxres)
+       ("startup-notification" ,startup-notification)))
+    (home-page "https://developer.gnome.org/libwnck/")
+    (synopsis "Window Navigator Construction Kit")
+    (description
+     "Libwnck is the Window Navigator Construction Kit, a library for use in
+writing pagers, tasklists, and more generally applications that are dealing
+with window management.  It tries hard to respect the Extended Window Manager
+Hints specification (EWMH).")
+    (license license:lgpl2.0+)))
+
+;; stable version for gtk2, required by xfwm4.
+(define-public libwnck-1
+  (package (inherit libwnck)
+    (name "libwnck")
+    (version "2.30.7")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version) "/"
+                                  name "-" version ".tar.xz"))
+              (sha256
+               (base32
+                "15713yl0f8f3p99jzqqfmbicrdswd3vwpx7r3bkf1bgh6d9lvs4b"))))
+    (propagated-inputs
+     `(("gtk+" ,gtk+-2)
+       ("libxres" ,libxres)
+       ("startup-notification" ,startup-notification)))))
 
 (define-public goffice
   (package
@@ -1246,3 +1300,185 @@ engineering.")
     (description
      "The default GNOME 3 themes (Adwaita and some accessibility themes).")
     (license license:lgpl2.1+)))
+
+(define-public vala
+  (package
+    (name "vala")
+    (version "0.26.1")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version) "/"
+                                  name "-" version ".tar.xz"))
+              (sha256
+               (base32
+                "0swyym2papln0f62ah05dpvq3vv6fssap26jq2zqp9dkkaqsn1w4"))))
+    (build-system gnu-build-system)
+    (arguments '(#:make-flags '("CC=gcc")))
+    (native-inputs
+     `(("pkg-config" ,pkg-config)
+       ("flex" ,flex)
+       ("bison" ,bison)
+       ("xsltproc" ,libxslt)
+       ("dbus" ,dbus)                                     ; for dbus tests
+       ("gobject-introspection" ,gobject-introspection))) ; for gir tests
+    (propagated-inputs
+     `(("glib" ,glib))) ; required by libvala-0.26.pc
+    (home-page "http://live.gnome.org/Vala/")
+    (synopsis "Compiler for the GObject type system")
+    (description
+     "Vala is a programming language that aims to bring modern programming
+language features to GNOME developers without imposing any additional runtime
+requirements and without using a different ABI compared to applications and
+libraries written in C.")
+    (license license:lgpl2.1+)))
+
+(define-public vte
+  (package
+    (name "vte")
+    (version "0.38.2")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version) "/"
+                                  name "-" version ".tar.xz"))
+              (sha256
+               (base32
+                "1rbxrigff9yszbgdw0gw4c2saz4d1hbbpz21phzxx14w49wvmnmj"))))
+    (build-system gnu-build-system)
+    (native-inputs
+     `(("pkg-config" ,pkg-config)
+       ("intltool" ,intltool)
+       ("vala" ,vala)
+       ("gobject-introspection" ,gobject-introspection)
+       ("glib" ,glib "bin") ; for glib-genmarshal, etc.
+       ("xmllint" ,libxml2)))
+    (propagated-inputs
+     `(("gtk+" ,gtk+))) ; required by libvte-2.91.pc
+    (arguments
+     `(#:phases
+       (alist-cons-before
+        'build 'pre-build
+        (lambda* _
+          (setenv "CC" "gcc"))
+        %standard-phases)))
+    (home-page "http://www.gnome.org/")
+    (synopsis "Virtual Terminal Emulator")
+    (description
+     "VTE is a library (libvte) implementing a terminal emulator widget for
+GTK+, and a minimal sample application (vte) using that.  Vte is mainly used in
+gnome-terminal, but can also be used to embed a console/terminal in games,
+editors, IDEs, etc.")
+    (license license:lgpl2.1+)))
+
+;; stable version for gtk2, required by xfce4-terminal.
+(define-public vte/gtk+-2
+  (package (inherit vte)
+    (name "vte")
+    (version "0.28.2")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version) "/"
+                                  name "-" version ".tar.xz"))
+              (sha256
+               (base32
+                "1bmhahkf8wdsra9whd3k5l5z4rv7r58ksr8mshzajgq2ma0hpkw6"))))
+    (arguments
+     '(#:configure-flags '("--disable-python")))
+    (native-inputs
+     `(("pkg-config" ,pkg-config)
+       ("intltool" ,intltool)
+       ("glib" ,glib "bin")))   ; for glib-genmarshal, etc.
+    (propagated-inputs
+     `(("gtk+" ,gtk+-2)         ; required by libvte.pc
+       ("ncurses" ,ncurses))))) ; required by libvte.la
+
+(define-public dconf
+  (package
+    (name "dconf")
+    (version "0.22.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append
+                    "mirror://gnome/sources/" name "/" 
+                    (version-major+minor version) "/"
+                    name "-" version ".tar.xz"))
+              (sha256
+               (base32 "13jb49504bir814v8n8vjip5sazwfwsrnniw87cpg7phqfq7q9qa"))))
+    (build-system glib-or-gtk-build-system)
+    (inputs
+     `(("gtk+" ,gtk+)
+       ("glib" ,glib)
+       ("dbus" ,dbus)
+       ("libxml2" ,libxml2)))
+    (native-inputs
+     `(("libxslt" ,libxslt)
+       ("docbook-xml" ,docbook-xml-4.2)
+       ("docbook-xsl" ,docbook-xsl)
+       ("intltool" ,intltool)
+       ("pkg-config" ,pkg-config)))
+    (arguments
+     `(#:tests? #f ; To contact dbus it needs to load /var/lib/dbus/machine-id
+                   ; or /etc/machine-id.
+       #:configure-flags
+       ;; Set the correct RUNPATH in binaries.
+       (list (string-append "LDFLAGS=-Wl,-rpath=" 
+                            (assoc-ref %outputs "out") "/lib")
+             "--disable-gtk-doc-html") ; FIXME: requires gtk-doc
+       #:phases
+       (alist-cons-before
+        'configure 'fix-docbook
+        (lambda* (#:key inputs #:allow-other-keys)
+          (substitute* "docs/Makefile.in"
+            (("http://docbook.sourceforge.net/release/xsl/current/manpages/docbook.xsl")
+             (string-append (assoc-ref inputs "docbook-xsl") 
+                            "/xml/xsl/docbook-xsl-"
+                            ,(package-version docbook-xsl)
+                            "/manpages/docbook.xsl")))
+          (setenv "XML_CATALOG_FILES" 
+                  (string-append (assoc-ref inputs "docbook-xml") 
+                                 "/xml/dtd/docbook/catalog.xml")))
+        %standard-phases)))
+    (home-page "https://developer.gnome.org/dconf")
+    (synopsis "Low-level GNOME configuration system")
+    (description "Dconf is a low-level configuration system.  Its main purpose
+is to provide a backend to GSettings on platforms that don't already have
+configuration storage systems.")
+    (license license:lgpl2.1)))
+
+(define-public json-glib
+  (package
+    (name "json-glib")
+    (version "1.0.2")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version) "/"
+                                  name "-" version ".tar.xz"))
+              (sha256
+               (base32
+                "02k66lpc4cmgygj66n8zcy59bggy7yzm3v4hni9xqplgva9d2yw8"))))
+    (build-system gnu-build-system)
+    (arguments
+     '(#:phases (alist-cons-before
+                 'build 'set-cc
+                 (lambda _
+                   ;; Set $CC so that g-ir-scanner works.
+                   (setenv "CC" "gcc")
+                   #t)
+                 %standard-phases)))
+    (native-inputs
+     `(("glib" ,glib "bin")              ;for glib-mkenums and glib-genmarshal
+       ("gobject-introspection" ,gobject-introspection)
+       ("pkg-config" ,pkg-config)))
+    (propagated-inputs
+     `(("glib" ,glib)))                         ;according to json-glib-1.0.pc
+    (home-page "https://wiki.gnome.org/Projects/JsonGlib")
+    (synopsis "Compiler for the GObject type system")
+    (description "JSON-GLib is a C library based on GLib providing
+serialization and deserialization support for the JavaScript Object Notation
+(JSON) format described by RFC 4627.  It provides parser and generator
+GObject classes and various wrappers for the complex data types employed by
+JSON, such as arrays and objects.")
+    (license license:lgpl2.1+)))
