@@ -1,7 +1,8 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
-;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
+;;; Copyright © 2014, 2015 Mark H Weaver <mhw@netris.org>
 ;;; Copyright © 2014 Alex Kost <alezost@gmail.com>
+;;; Copyright © 2014 Ricardo Wurmus <rekado@elephly.net>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -38,7 +39,7 @@
 (define-public libpng
   (package
    (name "libpng")
-   (version "1.5.17")
+   (version "1.5.21")
    (source (origin
             (method url-fetch)
 
@@ -49,7 +50,7 @@
                         "ftp://ftp.simplesystems.org/pub/libpng/png/src"
                         "/libpng15/libpng-" version ".tar.xz")))
             (sha256
-             (base32 "19wj293r4plbfgb43yhrc2qx8bsch9gbazazfqrj9haa7lsk29jp"))))
+             (base32 "19yvzw6sf9gf7v25ha9bla8bw1nijh82wj8ag6brjj3hpij1q5dm"))))
    (build-system gnu-build-system)
 
    ;; libpng.la says "-lz", so propagate it.
@@ -187,16 +188,15 @@ work.")
 (define-public openjpeg
   (package
     (name "openjpeg")
-    (version "2.0.0")
+    (version "2.0.1")
     (source
       (origin
         (method url-fetch)
         (uri
-          (string-append "http://openjpeg.googlecode.com/files/" name "-"
-                         version ".tar.gz"))
+         (string-append "mirror://sourceforge/openjpeg.mirror/" name "-"
+                        version ".tar.gz"))
         (sha256
-          (base32 "1n05yrmscpgksrh2kfh12h18l0lw9j03mgmvwcg3hm8m0lwgak9k"))))
-
+         (base32 "1c2xc3nl2mg511b63rk7hrckmy14681p1m44mzw3n1fyqnjm0b0z"))))
     (build-system cmake-build-system)
     (arguments
       ;; Trying to run `$ make check' results in a no rule fault.
@@ -217,9 +217,22 @@ In addition to the basic codec, various other features are under
 development, among them the JP2 and MJ2 (Motion JPEG 2000) file formats,
 an indexing tool useful for the JPIP protocol, JPWL-tools for
 error-resilience, a Java-viewer for j2k-images, ...")
-    (home-page "http://jbig2dec.sourceforge.net/")
+    (home-page "https://code.google.com/p/openjpeg/")
     (license license:bsd-2)))
 
+(define-public openjpeg-1
+  (package (inherit openjpeg)
+    (name "openjpeg")
+    (version "1.5.2")
+    (source
+     (origin
+       (method url-fetch)
+       (uri
+        (string-append "mirror://sourceforge/openjpeg.mirror/" name "-"
+                       version ".tar.gz"))
+       (sha256
+        (base32 "11waq9w215zvzxrpv40afyd18qf79mxc28fda80bm3ax98cpppqm"))))))
+
 (define-public giflib
   (package
     (name "giflib")
