@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013, 2014 Andreas Enge <andreas@enge.fr>
+;;; Copyright © 2013, 2014, 2015 Andreas Enge <andreas@enge.fr>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -31,6 +31,7 @@
   #:use-module (gnu packages python)
   #:use-module (gnu packages qt)
   #:use-module (gnu packages rdf)
+  #:use-module (gnu packages ruby)
   #:use-module (gnu packages video)
   #:use-module (gnu packages xml)
   #:use-module (gnu packages xorg))
@@ -60,26 +61,26 @@
 (define-public phonon
   (package
     (name "phonon")
-    (version "4.8.2")
+    (version "4.8.3")
     (source (origin
              (method url-fetch)
              (uri (string-append "http://download.kde.org/stable/" name
-                                "/" version "/"
+                                "/" version "/src/"
                                 name "-" version ".tar.xz"))
              (sha256
               (base32
-               "0xnjz7bbw393q77n4s6y9frd7l2s90635w03w9a2jr85zr89fnfg"))))
+               "05nshngk03ln90vsjz44dx8al576f4vd5fvhs1l0jmx13jb9q551"))))
     (build-system cmake-build-system)
-    ;; FIXME: Add interpreter ruby once available.
-    ;; Add optional input libqtzeitgeist.
-    (inputs
-     `(("automoc4" ,automoc4)
-       ("glib" ,glib)
-       ("libx11" ,libx11)
-       ("pulseaudio" ,pulseaudio)
-       ("qt" ,qt-4)))
+    ;; FIXME: Add optional input libqzeitgeist once available.
     (native-inputs
-     `(("pkg-config" ,pkg-config)))
+     `(("automoc4" ,automoc4)
+       ("pkg-config" ,pkg-config)))
+    (inputs
+     `(("glib" ,glib)
+       ("libx11" ,libx11)
+       ("pulseaudio" ,pulseaudio)))
+    (propagated-inputs
+     `(("qt" ,qt-4))) ; according to phonon.pc
     (arguments
      `(#:tests? #f)) ; no test target
     (home-page "http://phonon.kde.org/")
@@ -153,7 +154,7 @@ and import their menus over DBus.")
     (build-system cmake-build-system)
     (inputs
      `(("qt" ,qt-4)))
-    (home-page "https://projects.kde.org/projects/kdesupport/attica")
+    (home-page "https://projects.kde.org/projects/frameworks/attica")
     (synopsis "Qt library for the Open Collaboration Services API")
     (description "Attica is a Qt library that implements the Open
 Collaboration Services API version 1.6.  It grants easy access to the
