@@ -17,23 +17,28 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages lsof)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'license:))
+  #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix build-system gnu)
   #:use-module (gnu packages perl))
 
+(define %ftp-base
+  "ftp://lsof.itap.purdue.edu/pub/tools/unix/lsof/")
+
 (define-public lsof
   (package
    (name "lsof")
-   (version "4.87")
+   (version "4.88")
    (source (origin
             (method url-fetch)
-            (uri (string-append "ftp://lsof.itap.purdue.edu/pub/tools/unix/lsof/lsof_"
-                                version ".tar.bz2"))
-            (sha256 (base32
-                     "0b6si72sml7gr9784ak491cxxbm9mx5bh174yg6rrirbv04kgpfz"))))
+            (uri (list (string-append %ftp-base "lsof_"
+                                      version ".tar.bz2")
+                       (string-append %ftp-base "OLD/lsof_"
+                                      version ".tar.bz2")))
+            (sha256
+             (base32
+              "16y9wm26rg81mihnzcbdg8h8vhxmq8kn62ssxb8cqydp4q79nvzy"))))
    (build-system gnu-build-system)
    (inputs `(("perl" ,perl)))
    (arguments
@@ -64,7 +69,7 @@
            (copy-file "lsof.8" (string-append out "/share/man/man8/lsof.8"))
          ))
        %standard-phases)))))
-   (synopsis "lsof displays information about open files")
+   (synopsis "Display information about open files")
    (description
     "Lsof stands for LiSt Open Files, and it does just that.
 It lists information about files that are open by the processes running
