@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -64,7 +64,7 @@ data as produced by digital cameras.")
     (native-inputs `(("pkg-config" ,pkg-config)))
     (inputs
      `(;; ("libjpeg-turbo" ,libjpeg-turbo)
-       ("libtool" ,libtool)
+       ("libltdl" ,libltdl)
        ("libusb" ,libusb)))
     (propagated-inputs
      `(;; The .pc refers to libexif.
