@@ -1,5 +1,6 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013, 2014 Andreas Enge <andreas@enge.fr>
+;;; Copyright © 2013, 2014, 2015 Andreas Enge <andreas@enge.fr>
+;;; Copyright © 2015 Ricardo Wurmus <rekado@elephly.net>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -17,37 +18,43 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages rdf)
-  #:use-module ((guix licenses) #:select (lgpl2.0+ lgpl2.1 lgpl2.1+))
+  #:use-module ((guix licenses)
+                #:select (bsd-style gpl2 lgpl2.0+ lgpl2.1 lgpl2.1+))
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix build-system cmake)
   #:use-module (guix build-system gnu)
+  #:use-module (guix build-system python)
   #:use-module (gnu packages)
+  #:use-module (gnu packages autotools)
   #:use-module (gnu packages databases)
   #:use-module (gnu packages boost)
   #:use-module (gnu packages compression)
   #:use-module (gnu packages curl)
+  #:use-module (gnu packages cyrus-sasl)
   #:use-module (gnu packages doxygen)
   #:use-module (gnu packages gnupg)
   #:use-module (gnu packages linux)
   #:use-module (gnu packages multiprecision)
+  #:use-module (gnu packages openssl)
   #:use-module (gnu packages pcre)
   #:use-module (gnu packages perl)
   #:use-module (gnu packages pkg-config)
+  #:use-module (gnu packages python)
   #:use-module (gnu packages qt)
   #:use-module (gnu packages xml))
 
 (define-public raptor2
   (package
     (name "raptor2")
-    (version "2.0.11")
+    (version "2.0.15")
     (source (origin
              (method url-fetch)
              (uri (string-append "http://download.librdf.org/source/" name
                                  "-" version ".tar.gz"))
              (sha256
               (base32
-               "1z3i4fs32wcq5y9l7gdn7262h6r0ppdpvx4gw6jgsym8z083w0xf"))))
+               "1vc02im4mpc28zxzgli68k6j0dakh0k3s389bm436yvqajxg19xd"))))
     (build-system gnu-build-system)
     (inputs
      `(("curl" ,curl)
@@ -104,17 +111,69 @@ full-featured indexing and searching API.  It is a port of the very popular
 Java Lucene text search engine API to C++.")
     (license lgpl2.1)))
 
+(define-public lrdf
+  (package
+    (name "lrdf")
+    (version "0.5.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "https://github.com/swh/LRDF/archive/"
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "18p2flb2sv2hq6w2qkd29z9c7knnwqr3f12i2srshlzx6vwkm05s"))))
+    (build-system gnu-build-system)
+    (arguments
+     '(#:phases (alist-cons-after
+                 'unpack 'remove-out-of-tree-references
+                 (lambda _
+                   ;; remove symlinks to files in /usr/
+                   (delete-file-recursively "m4")
+                   (for-each delete-file '("config.guess"
+                                           "config.sub"
+                                           "depcomp"
+                                           "install-sh"
+                                           "ltmain.sh"
+                                           "missing"))
+                   ;; remove_test depends on an out-of-tree RDF file
+                   (substitute* "examples/Makefile.am"
+                     (("instances_test remove_test") "instances_test")
+                     (("\\$\\(TESTS\\) remove_test") "$(TESTS)")))
+                 (alist-cons-before
+                  'configure 'autoreconf
+                  (lambda* (#:key inputs #:allow-other-keys)
+                    (zero? (system* "autoreconf" "-vfi")))
+                  %standard-phases))))
+    (inputs
+     `(("raptor" ,raptor2)
+       ("cyrus-sasl" ,cyrus-sasl)
+       ("openssl" ,openssl)
+       ("zlib" ,zlib)))
+    (native-inputs
+     `(("autoconf" ,autoconf)
+       ("automake" ,automake)
+       ("libtool" ,libtool)
+       ("pkg-config" ,pkg-config)))
+    (home-page "https://github.com/swh/LRDF")
+    (synopsis "Lightweight RDF library for accessing LADSPA plugin metadata")
+    (description
+     "LRDF is a library to make it easy to manipulate RDF files describing
+LADSPA plugins.  It can also be used for general RDF manipulation.  It can
+read RDF/XLM and N3 files and export N3 files, and it also has a light
+taxonomic inference capablility.")
+    (license gpl2)))
+
 (define-public rasqal
   (package
     (name "rasqal")
-    (version "0.9.32")
+    (version "0.9.33")
     (source (origin
              (method url-fetch)
              (uri (string-append "http://download.librdf.org/source/" name
                                  "-" version ".tar.gz"))
              (sha256
               (base32
-               "13rfprkk7d74065c7bafyshajwa6lshj7m9l741zlz9viqhh7fpf"))))
+               "0z6rrwn4jsagvarg8d5zf0j352kjgi33py39jqd29gbhcnncj939"))))
     (build-system gnu-build-system)
     (native-inputs
      `(("perl" ,perl)
@@ -198,3 +257,32 @@ provides a highly usable object-oriented C++/Qt4 framework for RDF data.  It
 uses different RDF storage solutions as backends through a simple plugin
 system.")
     (license lgpl2.0+)))
+
+(define-public python-rdflib
+  (package
+    (name "python-rdflib")
+    (version "4.1.2")
+    (source
+      (origin
+        (method url-fetch)
+        (uri (string-append
+              "https://pypi.python.org/packages/source/r/rdflib/rdflib-"
+              version
+              ".tar.gz"))
+        (sha256
+          (base32
+            "0kvaf332cqbi47rqzlpdx4mbkvw12mkrzkj8n9l19wk713d4py9w"))))
+    (build-system python-build-system)
+    (inputs
+      `(("python-htm5lib" ,python-html5lib)
+        ("python-isodate" ,python-isodate)
+        ("python-pyparsing" ,python-pyparsing)
+        ("python-setuptools" ,python-setuptools)))
+    (home-page "https://github.com/RDFLib/rdflib")
+    (synopsis
+      "Python RDF library")
+    (description
+      "RDFLib is a Python library for working with RDF, a simple yet
+powerful language for representing information.")
+    (license (bsd-style "file://LICENSE"
+                        "See LICENSE in the distribution."))))
