@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2014 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
 ;;;
 ;;; This file is part of GNU Guix.
@@ -32,14 +32,14 @@
 (define-public tor
   (package
     (name "tor")
-    (version "0.2.4.22")
+    (version "0.2.5.10")
     (source (origin
              (method url-fetch)
              (uri (string-append "https://www.torproject.org/dist/tor-"
                                  version ".tar.gz"))
              (sha256
               (base32
-               "0k39ppcvld6p08yaf4rpspb34z4f5863j0d605yrm4dqjcp99xvb"))))
+               "0fx8qnwh2f8ykfx0np4hyznjfi4xfy96z59pk96y3zyjvjjh5pdk"))))
     (build-system gnu-build-system)
     (inputs
      `(("zlib" ,zlib)
@@ -49,13 +49,13 @@
     ;; TODO: Recommend `torsocks' since `torify' needs it.
 
     (home-page "http://www.torproject.org/")
-    (synopsis "An anonymous network router to improve privacy on the Internet")
+    (synopsis "Anonymous network router to improve privacy on the Internet")
     (description
      "Tor protects you by bouncing your communications around a distributed
 network of relays run by volunteers all around the world: it prevents
 somebody watching your Internet connection from learning what sites you
 visit, and it prevents the sites you visit from learning your physical
-location. Tor works with many of your existing applications, including
+location.  Tor works with many of your existing applications, including
 web browsers, instant messaging clients, remote login, and other
 applications based on the TCP protocol.")
     (license bsd-3)))
