@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2014 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -28,15 +28,14 @@
 (define-public valgrind
   (package
     (name "valgrind")
-    (version "3.9.0")
+    (version "3.10.0")
     (source (origin
              (method url-fetch)
              (uri (string-append "http://valgrind.org/downloads/valgrind-"
                                  version ".tar.bz2"))
              (sha256
               (base32
-               "1w6n5qvxy2ssbczcl1c2yd2ggjn3ipay2hvpn10laly2dfh73bz6"))
-             (patches (list (search-patch "valgrind-glibc.patch")))))
+               "1jgd42vsx0bcblp91bd61hd5wpy0gghh09wxgm65m666vy17y103"))))
     (build-system gnu-build-system)
     (arguments
      '(#:phases (alist-cons-after
@@ -59,6 +58,10 @@
     (description
      "Valgrind is an instrumentation framework for building dynamic analysis
 tools.  There are Valgrind tools that can automatically detect many memory
-management and threading bugs, and profile your programs in detail. You can
+management and threading bugs, and profile your programs in detail.  You can
 also use Valgrind to build new tools.")
-    (license gpl2+)))
+    (license gpl2+)
+
+    ;; Building VEX on mips64el-linux fails with "opcode not supported on this
+    ;; processor: mips3".
+    (supported-systems (delete "mips64el-linux" %supported-systems))))
