@@ -17,6 +17,7 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu services)
+  #:use-module (guix gexp)
   #:use-module (guix records)
   #:export (service?
             service
@@ -26,6 +27,7 @@
             service-respawn?
             service-start
             service-stop
+            service-auto-start?
             service-activate
             service-user-accounts
             service-user-groups
@@ -47,9 +49,11 @@
                  (default '()))
   (respawn?      service-respawn?                 ; Boolean
                  (default #t))
-  (start         service-start)                   ; g-expression
-  (stop          service-stop                     ; g-expression
-                 (default #f))
+  (start         service-start)                   ; g-expression (procedure)
+  (stop          service-stop                     ; g-expression (procedure)
+                 (default #~(const #f)))
+  (auto-start?   service-auto-start?              ; Boolean
+                 (default #t))
   (user-accounts service-user-accounts            ; list of <user-account>
                  (default '()))
   (user-groups   service-user-groups              ; list of <user-groups>
