@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -23,6 +23,8 @@
   #:use-module (guix derivations)
   #:use-module (guix packages)
   #:use-module (guix monads)
+  #:use-module (guix records)
+
   #:use-module ((gnu build vm)
                 #:select (qemu-command))
   #:use-module (gnu packages base)
@@ -55,6 +57,13 @@
   #:export (expression->derivation-in-linux-vm
             qemu-image
             system-qemu-image
+
+            file-system-mapping
+            file-system-mapping?
+            file-system-mapping-source
+            file-system-mapping-target
+            file-system-mapping-writable?
+
             system-qemu-image/shared-store
             system-qemu-image/shared-store-script
             system-disk-image))
@@ -95,7 +104,9 @@
                                               '((gnu build vm)
                                                 (gnu build install)
                                                 (gnu build linux-boot)
+                                                (gnu build linux-modules)
                                                 (gnu build file-systems)
+                                                (guix elf)
                                                 (guix build utils)
                                                 (guix build store-copy)))
                                              (guile-for-build
@@ -267,12 +278,11 @@ to USB sticks meant to be read-only."
 
   (let ((os (operating-system (inherit os)
               ;; Since this is meant to be used on real hardware, don't
-              ;; install QEMU networking or anything like that, but make sure
-              ;; USB mass storage devices are available.
+              ;; install QEMU networking or anything like that.  Assume USB
+              ;; mass storage devices (usb-storage.ko) are available.
               (initrd (lambda (file-systems . rest)
                         (apply base-initrd file-systems
                                #:volatile-root? #t
-                               #:extra-modules '("usb-storage.ko")
                                rest)))
 
               ;; Force our own root file system.
@@ -338,9 +348,65 @@ of the GNU system as described by OS."
                               ("grub.cfg" ,grub.cfg))
                    #:copy-inputs? #t))))
 
-(define (virtualized-operating-system os)
+
+;;;
+;;; VMs that share file systems with the host.
+;;;
+
+;; Mapping of host file system SOURCE to mount point TARGET in the guest.
+(define-record-type* <file-system-mapping> file-system-mapping
+  make-file-system-mapping
+  file-system-mapping?
+  (source    file-system-mapping-source)          ;string
+  (target    file-system-mapping-target)          ;string
+  (writable? file-system-mapping-writable?        ;Boolean
+             (default #f)))
+
+(define %store-mapping
+  ;; Mapping of the host's store into the guest.
+  (file-system-mapping
+   (source (%store-prefix))
+   (target (%store-prefix))
+   (writable? #f)))
+
+(define (file-system->mount-tag fs)
+  "Return a 9p mount tag for host file system FS."
+  ;; QEMU mount tags cannot contain slashes and cannot start with '_'.
+  ;; Compute an identifier that corresponds to the rules.
+  (string-append "TAG"
+                 (string-map (match-lambda
+                              (#\/ #\_)
+                              (chr chr))
+                             fs)))
+
+(define (mapping->file-system mapping)
+  "Return a 9p file system that realizes MAPPING."
+  (match mapping
+    (($ <file-system-mapping> source target writable?)
+     (file-system
+       (mount-point target)
+       (device (file-system->mount-tag source))
+       (type "9p")
+       (flags (if writable? '() '(read-only)))
+       (options (string-append "trans=virtio"))
+       (check? #f)
+       (create-mount-point? #t)))))
+
+(define (virtualized-operating-system os mappings)
   "Return an operating system based on OS suitable for use in a virtualized
-environment with the store shared with the host."
+environment with the store shared with the host.  MAPPINGS is a list of
+<file-system-mapping> to realize in the virtualized OS."
+  (define user-file-systems
+    ;; Remove file systems that conflict with those added below, or that are
+    ;; normally bound to real devices.
+    (remove (lambda (fs)
+              (let ((target (file-system-mount-point fs))
+                    (source (file-system-device fs)))
+                (or (string=? target (%store-prefix))
+                    (string=? target "/")
+                    (string-prefix? "/dev/" source))))
+            (operating-system-file-systems os)))
+
   (operating-system (inherit os)
     (initrd (lambda (file-systems . rest)
               (apply base-initrd file-systems
@@ -356,23 +422,13 @@ environment with the store shared with the host."
                            (mount-point "/")
                            (device "/dev/vda1")
                            (type "ext4"))
-                         (file-system
-                           (mount-point (%store-prefix))
-                           (device "store")
-                           (type "9p")
-                           (needed-for-boot? #t)
-                           (options "trans=virtio")
-                           (check? #f))
 
-                         ;; Remove file systems that conflict with those
-                         ;; above, or that are normally bound to real devices.
-                         (remove (lambda (fs)
-                                   (let ((target (file-system-mount-point fs))
-                                         (source (file-system-device fs)))
-                                     (or (string=? target (%store-prefix))
-                                         (string=? target "/")
-                                         (string-prefix? "/dev/" source))))
-                                 (operating-system-file-systems os))))))
+                         (file-system (inherit
+                                       (mapping->file-system %store-mapping))
+                            (needed-for-boot? #t))
+
+                         (append (map mapping->file-system mappings)
+                                 user-file-systems)))))
 
 (define* (system-qemu-image/shared-store
           os
@@ -402,13 +458,20 @@ bootloader refers to: OS kernel, initrd, bootloader data, etc."
                 #:register-closures? #f
                 #:copy-inputs? full-boot?)))
 
-(define* (common-qemu-options image)
-  "Return the a string-value gexp with the common QEMU options to boot IMAGE."
-#~(string-append
+(define* (common-qemu-options image shared-fs)
+  "Return the a string-value gexp with the common QEMU options to boot IMAGE,
+with '-virtfs' options for the host file systems listed in SHARED-FS."
+  (define (virtfs-option fs)
+    #~(string-append "-virtfs local,path=\"" #$fs
+                     "\",security_model=none,mount_tag=\""
+                     #$(file-system->mount-tag fs)
+                     "\" "))
+
+  #~(string-append
      " -enable-kvm -no-reboot -net nic,model=virtio \
-  -virtfs local,path=" #$(%store-prefix) ",security_model=none,mount_tag=store \
+  " #$@(map virtfs-option shared-fs) " \
   -net user \
-  -serial stdio \
+  -serial stdio -vga std \
   -drive file=" #$image
   ",if=virtio,cache=writeback,werror=report,readonly \
   -m 256"))
@@ -417,6 +480,7 @@ bootloader refers to: OS kernel, initrd, bootloader data, etc."
                                                 #:key
                                                 (qemu qemu)
                                                 (graphic? #t)
+                                                (mappings '())
                                                 full-boot?
                                                 (disk-image-size
                                                  (* (if full-boot? 500 15)
@@ -424,11 +488,14 @@ bootloader refers to: OS kernel, initrd, bootloader data, etc."
   "Return a derivation that builds a script to run a virtual machine image of
 OS that shares its store with the host.
 
+MAPPINGS is a list of <file-system-mapping> specifying mapping of host file
+systems into the guest.
+
 When FULL-BOOT? is true, the returned script runs everything starting from the
 bootloader; otherwise it directly starts the operating system kernel.  The
 DISK-IMAGE-SIZE parameter specifies the size in bytes of the root disk image;
 it is mostly useful when FULL-BOOT?  is true."
-  (mlet* %store-monad ((os ->  (virtualized-operating-system os))
+  (mlet* %store-monad ((os ->  (virtualized-operating-system os mappings))
                        (os-drv (operating-system-derivation os))
                        (image  (system-qemu-image/shared-store
                                 os
@@ -447,7 +514,9 @@ exec " #$qemu "/bin/" #$(qemu-command (%current-system))
             -initrd " #$os-drv "/initrd \
             -append \"" #$(if graphic? "" "console=ttyS0 ")
             "--system=" #$os-drv " --load=" #$os-drv "/boot --root=/dev/vda1\" "))
-#$(common-qemu-options image)
+#$(common-qemu-options image
+                       (map file-system-mapping-source
+                            (cons %store-mapping mappings)))
 " \"$@\"\n")
              port)
             (chmod port #o555))))
