@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -21,6 +21,8 @@
   #:use-module (srfi srfi-9)
   #:use-module (srfi srfi-9 gnu)
   #:use-module (srfi srfi-26)
+  #:use-module (srfi srfi-34)
+  #:use-module (srfi srfi-35)
   #:use-module (rnrs io ports)
   #:use-module (rnrs bytevectors)
   #:use-module (ice-9 match)
@@ -28,15 +30,18 @@
   #:use-module (ice-9 vlist)
   #:use-module (guix store)
   #:use-module (guix utils)
+  #:use-module (guix monads)
   #:use-module (guix hash)
   #:use-module (guix base32)
   #:use-module (guix records)
+  #:use-module (guix sets)
   #:export (<derivation>
             derivation?
             derivation-outputs
             derivation-inputs
             derivation-sources
             derivation-system
+            derivation-builder
             derivation-builder-arguments
             derivation-builder-environment-vars
             derivation-file-name
@@ -56,10 +61,19 @@
             derivation-input-sub-derivations
             derivation-input-output-paths
 
+            &derivation-error
+            derivation-error?
+            derivation-error-derivation
+            &derivation-missing-output-error
+            derivation-missing-output-error?
+            derivation-missing-output
+
             derivation-name
+            derivation-output-names
             fixed-output-derivation?
             offloadable-derivation?
             substitutable-derivation?
+            substitution-oracle
             derivation-hash
 
             read-derivation
@@ -80,13 +94,30 @@
 
             map-derivation
 
-            %guile-for-build
+            built-derivations
             imported-modules
             compiled-modules
+
             build-expression->derivation
             imported-files)
+
+  ;; Re-export it from here for backward compatibility.
+  #:re-export (%guile-for-build)
+
   #:replace (build-derivations))
 
+;;;
+;;; Error conditions.
+;;;
+
+(define-condition-type &derivation-error &nix-error
+  derivation-error?
+  (derivation derivation-error-derivation))
+
+(define-condition-type &derivation-missing-output-error &derivation-error
+  derivation-missing-output-error?
+  (output derivation-missing-output))
+
 ;;;
 ;;; Nix derivations, as implemented in Nix's `derivations.cc'.
 ;;;
@@ -134,6 +165,12 @@
   (let ((base (store-path-package-name (derivation-file-name drv))))
     (string-drop-right base 4)))
 
+(define (derivation-output-names drv)
+  "Return the names of the outputs of DRV."
+  (match (derivation-outputs drv)
+    (((names . _) ...)
+     names)))
+
 (define (fixed-output-derivation? drv)
   "Return #t if DRV is a fixed-output derivation, such as the result of a
 download with a fixed hash (aka. `fetchurl')."
@@ -153,16 +190,18 @@ download with a fixed hash (aka. `fetchurl')."
 
 (define (derivation-prerequisites drv)
   "Return the list of derivation-inputs required to build DRV, recursively."
-  (let loop ((drv    drv)
-             (result '()))
-    (let ((inputs (remove (cut member <> result)  ; XXX: quadratic
+  (let loop ((drv       drv)
+             (result    '())
+             (input-set (set)))
+    (let ((inputs (remove (cut set-contains? input-set <>)
                           (derivation-inputs drv))))
-      (fold loop
-            (append inputs result)
-            (map (lambda (i)
-                   (call-with-input-file (derivation-input-path i)
-                     read-derivation))
-                 inputs)))))
+      (fold2 loop
+             (append inputs result)
+             (fold set-insert input-set inputs)
+             (map (lambda (i)
+                    (call-with-input-file (derivation-input-path i)
+                      read-derivation))
+                  inputs)))))
 
 (define (offloadable-derivation? drv)
   "Return true if DRV can be offloaded, false otherwise."
@@ -176,41 +215,52 @@ download with a fixed hash (aka. `fetchurl')."
   ;; synonymous, see <http://bugs.gnu.org/18747>.
   offloadable-derivation?)
 
+(define (derivation-output-paths drv sub-drvs)
+  "Return the output paths of outputs SUB-DRVS of DRV."
+  (match drv
+    (($ <derivation> outputs)
+     (map (lambda (sub-drv)
+            (derivation-output-path (assoc-ref outputs sub-drv)))
+          sub-drvs))))
+
+(define* (substitution-oracle store drv)
+  "Return a one-argument procedure that, when passed a store file name,
+returns #t if it's substitutable and #f otherwise.  The returned procedure
+knows about all substitutes for all the derivations listed in DRV and their
+prerequisites.
+
+Creating a single oracle (thus making a single 'substitutable-paths' call) and
+reusing it is much more efficient than calling 'has-substitutes?' or similar
+repeatedly, because it avoids the costs associated with launching the
+substituter many times."
+  (let* ((paths (delete-duplicates
+                 (fold (lambda (drv result)
+                         (let ((self (match (derivation->output-paths drv)
+                                       (((names . paths) ...)
+                                        paths)))
+                               (deps (append-map derivation-input-output-paths
+                                                 (derivation-prerequisites
+                                                  drv))))
+                           (append self deps result)))
+                       '()
+                       drv)))
+         (subst (list->set (substitutable-paths store paths))))
+    (cut set-contains? subst <>)))
+
 (define* (derivation-prerequisites-to-build store drv
                                             #:key
                                             (outputs
-                                             (map
-                                              car
-                                              (derivation-outputs drv)))
-                                            (use-substitutes? #t))
+                                             (derivation-output-names drv))
+                                            (substitutable?
+                                             (substitution-oracle store
+                                                                  (list drv))))
   "Return two values: the list of derivation-inputs required to build the
 OUTPUTS of DRV and not already available in STORE, recursively, and the list
-of required store paths that can be substituted.  When USE-SUBSTITUTES? is #f,
-that second value is the empty list."
-  (define (derivation-output-paths drv sub-drvs)
-    (match drv
-      (($ <derivation> outputs)
-       (map (lambda (sub-drv)
-              (derivation-output-path (assoc-ref outputs sub-drv)))
-            sub-drvs))))
-
+of required store paths that can be substituted.  SUBSTITUTABLE? must be a
+one-argument procedure similar to that returned by 'substitution-oracle'."
   (define built?
     (cut valid-path? store <>))
 
-  (define substitutable?
-    ;; Return true if the given path is substitutable.  Call
-    ;; `substitutable-paths' upfront, to benefit from parallelism in the
-    ;; substituter.
-    (if use-substitutes?
-        (let ((s (substitutable-paths store
-                                      (append
-                                       (derivation-output-paths drv outputs)
-                                       (append-map
-                                        derivation-input-output-paths
-                                        (derivation-prerequisites drv))))))
-          (cut member <> s))
-        (const #f)))
-
   (define input-built?
     (compose (cut any built? <>) derivation-input-output-paths))
 
@@ -480,9 +530,15 @@ that form."
         (cut write-derivation drv <>))))))
 
 (define* (derivation->output-path drv #:optional (output "out"))
-  "Return the store path of its output OUTPUT."
-  (let ((outputs (derivation-outputs drv)))
-    (and=> (assoc-ref outputs output) derivation-output-path)))
+  "Return the store path of its output OUTPUT.  Raise a
+'&derivation-missing-output-error' condition if OUTPUT is not an output of
+DRV."
+  (let ((output* (assoc-ref (derivation-outputs drv) output)))
+    (if output*
+        (derivation-output-path output*)
+        (raise (condition (&derivation-missing-output-error
+                           (derivation drv)
+                           (output output)))))))
 
 (define (derivation->output-paths drv)
   "Return the list of name/path pairs of the outputs of DRV."
@@ -843,7 +899,7 @@ recursively."
                                                        replacements))))
                                     (derivation-builder-environment-vars drv))
                     #:inputs (append (map list sources) inputs)
-                    #:outputs (map car (derivation-outputs drv))
+                    #:outputs (derivation-output-names drv)
                     #:hash (match (derivation-outputs drv)
                              ((($ <derivation-output> _ algo hash))
                               hash)
@@ -872,11 +928,6 @@ recursively."
 ;;; Guile-based builders.
 ;;;
 
-(define %guile-for-build
-  ;; The derivation of the Guile to be used within the build environment,
-  ;; when using `build-expression->derivation'.
-  (make-parameter #f))
-
 (define (parent-directories file-name)
   "Return the list of parent dirs of FILE-NAME, in the order in which an
 `mkdir -p' implementation would make them."
@@ -933,11 +984,11 @@ system, imported, and appears under FINAL-PATH in the resulting store path."
   ;; up looking for the same files over and over again.
   (memoize search-path))
 
-(define* (imported-modules store modules
-                           #:key (name "module-import")
-                           (system (%current-system))
-                           (guile (%guile-for-build))
-                           (module-path %load-path))
+(define* (%imported-modules store modules
+                            #:key (name "module-import")
+                            (system (%current-system))
+                            (guile (%guile-for-build))
+                            (module-path %load-path))
   "Return a derivation that contains the source files of MODULES, a list of
 module names such as `(ice-9 q)'.  All of MODULES must be in the MODULE-PATH
 search path."
@@ -952,18 +1003,18 @@ search path."
     (imported-files store files #:name name #:system system
                     #:guile guile)))
 
-(define* (compiled-modules store modules
-                           #:key (name "module-import-compiled")
-                           (system (%current-system))
-                           (guile (%guile-for-build))
-                           (module-path %load-path))
+(define* (%compiled-modules store modules
+                            #:key (name "module-import-compiled")
+                            (system (%current-system))
+                            (guile (%guile-for-build))
+                            (module-path %load-path))
   "Return a derivation that builds a tree containing the `.go' files
 corresponding to MODULES.  All the MODULES are built in a context where
 they can refer to each other."
-  (let* ((module-drv (imported-modules store modules
-                                       #:system system
-                                       #:guile guile
-                                       #:module-path module-path))
+  (let* ((module-drv (%imported-modules store modules
+                                        #:system system
+                                        #:guile guile
+                                        #:module-path module-path))
          (module-dir (derivation->output-path module-drv))
          (files      (map (lambda (m)
                             (let ((f (string-join (map symbol->string m)
@@ -1195,15 +1246,15 @@ ALLOWED-REFERENCES, and LOCAL-BUILD?."
                                       (filter-map source-path inputs)))
 
          (mod-drv  (and (pair? modules)
-                        (imported-modules store modules
-                                          #:guile guile-drv
-                                          #:system system)))
+                        (%imported-modules store modules
+                                           #:guile guile-drv
+                                           #:system system)))
          (mod-dir  (and mod-drv
                         (derivation->output-path mod-drv)))
          (go-drv   (and (pair? modules)
-                        (compiled-modules store modules
-                                          #:guile guile-drv
-                                          #:system system)))
+                        (%compiled-modules store modules
+                                           #:guile guile-drv
+                                           #:system system)))
          (go-dir   (and go-drv
                         (derivation->output-path go-drv))))
     (derivation store name guile
@@ -1232,3 +1283,17 @@ ALLOWED-REFERENCES, and LOCAL-BUILD?."
                 #:references-graphs references-graphs
                 #:allowed-references allowed-references
                 #:local-build? local-build?)))
+
+
+;;;
+;;; Monadic interface.
+;;;
+
+(define built-derivations
+  (store-lift build-derivations))
+
+(define imported-modules
+  (store-lift %imported-modules))
+
+(define compiled-modules
+  (store-lift %compiled-modules))
