@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2013, 2014 Andreas Enge <andreas@enge.fr>
 ;;;
 ;;; This file is part of GNU Guix.
@@ -21,7 +21,7 @@
   #:use-module (ice-9 match)
   #:use-module (guix derivations)
   #:use-module (guix packages)
-  #:use-module ((guix store) #:select (derivation-path? add-to-store))
+  #:use-module (guix store)
   #:use-module ((guix build download) #:prefix build:)
   #:use-module (guix monads)
   #:use-module (guix gexp)
@@ -61,15 +61,23 @@
        ,@(map (cut string-append <> "/gcc") gnu-mirrors))
       (gnupg
        "ftp://gd.tuwien.ac.at/privacy/gnupg/"
-       "ftp://gnupg.x-zone.org/pub/gnupg/"
-       "ftp://ftp.gnupg.cz/pub/gcrypt/"
-       "ftp://sunsite.dk/pub/security/gcrypt/"
-       "http://gnupg.wildyou.net/"
-       "http://ftp.gnupg.zone-h.org/"
-       "ftp://ftp.jyu.fi/pub/crypt/gcrypt/"
-       "ftp://trumpetti.atm.tut.fi/gcrypt/"
+       "ftp://mirrors.dotsrc.org/gcrypt/"
        "ftp://mirror.cict.fr/gnupg/"
-       "ftp://ftp.strasbourg.linuxfr.org/pub/gnupg/")
+       "http://artfiles.org/gnupg.org"
+       "ftp://ftp.franken.de/pub/crypt/mirror/ftp.gnupg.org/gcrypt/"
+       "ftp://ftp.freenet.de/pub/ftp.gnupg.org/gcrypt/"
+       "http://www.crysys.hu/"
+       "ftp://ftp.hi.is/pub/mirrors/gnupg/"
+       "ftp://ftp.heanet.ie/mirrors/ftp.gnupg.org/gcrypt/"
+       "ftp://ftp.bit.nl/mirror/gnupg/"
+       "ftp://ftp.surfnet.nl/pub/security/gnupg/"
+       "ftp://ftp.iasi.roedu.net/pub/mirrors/ftp.gnupg.org/"
+       "ftp://ftp.sunet.se/pub/security/gnupg/"
+       "ftp://mirror.switch.ch/mirror/gnupg/"
+       "ftp://mirror.tje.me.uk/pub/mirrors/ftp.gnupg.org/"
+       "ftp://ftp.mirrorservice.org/sites/ftp.gnupg.org/gcrypt/"
+       "ftp://ftp.ring.gr.jp/pub/net/gnupg/"
+       "ftp://ftp.gnupg.org/gcrypt/")
       (gnome
        "http://ftp.belnet.be/ftp.gnome.org/"
        "http://ftp.linux.org.uk/mirrors/ftp.gnome.org/"
@@ -189,27 +197,22 @@
   (let ((module (resolve-interface '(gnu packages gnutls))))
     (module-ref module 'gnutls)))
 
-(define* (url-fetch store url hash-algo hash
+(define* (url-fetch url hash-algo hash
                     #:optional name
-                    #:key (system (%current-system)) guile
+                    #:key (system (%current-system))
+                    (guile (default-guile))
                     (mirrors %mirrors))
-  "Return the path of a fixed-output derivation in STORE that fetches
-URL (a string, or a list of strings denoting alternate URLs), which is
-expected to have hash HASH of type HASH-ALGO (a symbol).  By default,
-the file name is the base name of URL; optionally, NAME can specify a
-different file name.
+  "Return a fixed-output derivation that fetches URL (a string, or a list of
+strings denoting alternate URLs), which is expected to have hash HASH of type
+HASH-ALGO (a symbol).  By default, the file name is the base name of URL;
+optionally, NAME can specify a different file name.
 
 When one of the URL starts with mirror://, then its host part is
 interpreted as the name of a mirror scheme, taken from MIRRORS; MIRRORS
-must be a list of symbol/URL-list pairs."
-  (define guile-for-build
-    (package-derivation store
-                        (or guile
-                            (let ((distro (resolve-interface
-                                           '(gnu packages commencement))))
-                              (module-ref distro 'guile-final)))
-                        system))
+must be a list of symbol/URL-list pairs.
 
+Alternately, when URL starts with file://, return the corresponding file name
+in the store."
   (define file-name
     (match url
       ((head _ ...)
@@ -246,26 +249,24 @@ must be a list of symbol/URL-list pairs."
   (let ((uri (and (string? url) (string->uri url))))
     (if (or (and (string? url) (not uri))
             (and uri (memq (uri-scheme uri) '(#f file))))
-        (add-to-store store (or name file-name)
-                      #f "sha256" (if uri (uri-path uri) url))
-        (run-with-store store
+        (interned-file (if uri (uri-path uri) url)
+                       (or name file-name))
+        (mlet %store-monad ((guile (package->derivation guile system)))
           (gexp->derivation (or name file-name) builder
+                            #:guile-for-build guile
                             #:system system
                             #:hash-algo hash-algo
                             #:hash hash
                             #:modules '((guix build download)
                                         (guix build utils)
                                         (guix ftp-client))
-                            #:guile-for-build guile-for-build
 
                             ;; In general, offloading downloads is not a good idea.
                             ;;#:local-build? #t
                             ;; FIXME: The above would also disable use of
                             ;; substitutes, so comment it out; see
                             ;; <https://bugs.gnu.org/18747>.
-                            )
-          #:guile-for-build guile-for-build
-          #:system system))))
+                            )))))
 
 (define* (download-to-store store url #:optional (name (basename url))
                             #:key (log (current-error-port)))
