@@ -28,6 +28,7 @@
             cc0
             cddl1.0
             cecill-c
+            clarified-artistic
             cpl1.0
             epl1.0
             expat
@@ -39,7 +40,8 @@
             ibmpl1.0
             imlib2
             lgpl2.0 lgpl2.0+ lgpl2.1 lgpl2.1+ lgpl3 lgpl3+
-            mpl2.0
+            mpl1.1 mpl2.0
+            ncsa
             openldap2.8 openssl
             psfl public-domain
             qpl
@@ -127,6 +129,12 @@ which may be a file:// URI pointing the package's tree."
            "http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html"
            "https://www.gnu.org/licenses/license-list.html#CeCILL"))
 
+(define clarified-artistic
+  (license "Clarified Artistic"
+           ;; http://directory.fsf.org/wiki/User:Jgay/license-categorization#Clarified_Artistic_License
+           "http://gianluca.dellavedova.org/2011/01/03/clarified-artistic-license/"
+           "https://www.gnu.org/licenses/license-list.html#ArtisticLicense2"))
+
 (define cpl1.0
   (license "CPL 1.0"
            "http://directory.fsf.org/wiki/License:CPLv1.0"
@@ -232,11 +240,21 @@ which may be a file:// URI pointing the package's tree."
            "https://www.gnu.org/licenses/lgpl.html"
            "https://www.gnu.org/licenses/license-list#LGPLv3"))
 
+(define mpl1.1
+  (license "MPL 1.1"
+           "http://directory.fsf.org/wiki/License:MPLv1.1"
+           "https://www.gnu.org/licenses/license-list#MPL"))
+
 (define mpl2.0
   (license "MPL 2.0"
            "http://directory.fsf.org/wiki/License:MPLv2.0"
            "https://www.gnu.org/licenses/license-list#MPL-2.0"))
 
+(define ncsa
+  (license "NCSA/University of Illinois Open Source License"
+           "http://directory.fsf.org/wiki/License:IllinoisNCSA"
+           "https://www.gnu.org/licenses/license-list#NCSA"))
+
 (define openssl
   (license "OpenSSL"
            "http://directory.fsf.org/wiki/License:OpenSSL"
