@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -17,15 +17,15 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (guix pk-crypto)
-  #:use-module (guix config)
   #:use-module ((guix utils)
                 #:select (bytevector->base16-string
                           base16-string->bytevector))
+  #:use-module (guix gcrypt)
+
   #:use-module (system foreign)
   #:use-module (rnrs bytevectors)
   #:use-module (ice-9 match)
-  #:export (gcrypt-version
-            canonical-sexp?
+  #:export (canonical-sexp?
             error-source
             error-string
             string->canonical-sexp
@@ -46,7 +46,8 @@
             generate-key
             find-sexp-token
             canonical-sexp->sexp
-            sexp->canonical-sexp))
+            sexp->canonical-sexp)
+  #:re-export (gcrypt-version))
 
 
 ;;; Commentary:
@@ -81,23 +82,6 @@
             (number->string (pointer-address (canonical-sexp->pointer obj))
                             16))))
 
-(define libgcrypt-func
-  (let ((lib (dynamic-link %libgcrypt)))
-    (lambda (func)
-      "Return a pointer to symbol FUNC in libgcrypt."
-      (dynamic-func func lib))))
-
-(define gcrypt-version
-  ;; According to the manual, this function must be called before any other,
-  ;; and it's not clear whether it can be called more than once.  So call it
-  ;; right here from the top level.
-  (let* ((ptr     (libgcrypt-func "gcry_check_version"))
-         (proc    (pointer->procedure '* ptr '(*)))
-         (version (pointer->string (proc %null-pointer))))
-    (lambda ()
-      "Return the version number of libgcrypt as a string."
-      version)))
-
 (define finalize-canonical-sexp!
   (libgcrypt-func "gcry_sexp_release"))
 
@@ -254,9 +238,9 @@ Return #f if that element does not exist, or if it's a list."
                                 #:optional
                                 (hash-algo "sha256")
                                 #:key (key-type 'ecc))
-  "Given BV, a bytevector containing a hash, return an s-expression suitable
-for use as the data for 'sign'.  KEY-TYPE must be a symbol: 'dsa, 'ecc, or
-'rsa."
+  "Given BV, a bytevector containing a hash of type HASH-ALGO, return an
+s-expression suitable for use as the 'data' argument for 'sign'.  KEY-TYPE
+must be a symbol: 'dsa, 'ecc, or 'rsa."
   (string->canonical-sexp
    (format #f "(data (flags ~a) (hash \"~a\" #~a#))"
            (case key-type
@@ -289,8 +273,10 @@ Return #f if DATA does not conform."
   (let* ((ptr  (libgcrypt-func "gcry_pk_sign"))
          (proc (pointer->procedure int ptr '(* * *))))
     (lambda (data secret-key)
-      "Sign DATA (an s-expression) with SECRET-KEY (an s-expression whose car
-is 'private-key'.)"
+      "Sign DATA, a canonical s-expression representing a suitable hash, with
+SECRET-KEY (a canonical s-expression whose car is 'private-key'.)  Note that
+DATA must be a 'data' s-expression, as returned by
+'bytevector->hash-data' (info \"(gcrypt) Cryptographic Functions\")."
       (let* ((sig (bytevector->pointer (make-bytevector (sizeof '*))))
              (err (proc sig (canonical-sexp->pointer data)
                         (canonical-sexp->pointer secret-key))))
