@@ -21,6 +21,7 @@
   #:use-module (guix records)
   #:use-module (guix store)
   #:use-module (guix derivations)
+  #:use-module (guix serialization)
   #:use-module (guix nar)
   #:use-module (guix utils)
   #:use-module ((guix build utils) #:select (which mkdir-p))
@@ -181,7 +182,8 @@ determined."
                       #:key (error-port (current-error-port)) (quote? #t))
   "Run COMMAND (a string list) on MACHINE, assuming an lsh gateway has been
 set up.  When QUOTE? is true, perform shell-quotation of all the elements of
-COMMAND."
+COMMAND.  Return either a pipe opened with MODE, or #f if the lsh client could
+not be started."
   (define (shell-quote str)
     ;; Sort-of shell-quote STR so it can be passed as an argument to the
     ;; shell.
@@ -315,8 +317,17 @@ hook."
        (let ((root-directory (string-append %state-directory
                                             "/gcroots/tmp")))
          (false-if-exception (mkdir root-directory))
-         (symlink ,file
-                  (string-append root-directory "/" ,%gc-root-file)))))
+         (catch 'system-error
+           (lambda ()
+             (symlink ,file
+                      (string-append root-directory "/" ,%gc-root-file)))
+           (lambda args
+             ;; If FILE already exists, we can assume that either it's a stale
+             ;; reference (which is fine), or another process is already
+             ;; building the derivation represented by FILE (which is fine
+             ;; too.)  Thus, do nothing in that case.
+             (unless (= EEXIST (system-error-errno args))
+               (apply throw args)))))))
 
   (let ((pipe (remote-pipe machine OPEN_READ
                            `("guile" "-c" ,(object->string script)))))
@@ -399,10 +410,7 @@ there, and write the build log to LOG-PORT.  Return the exit status."
   "Offload DRV to MACHINE.  Prior to the actual offloading, transfer all of
 INPUTS to MACHINE; if building DRV succeeds, retrieve all of OUTPUTS from
 MACHINE."
-  ;; Acquire MACHINE's upload or download lock to serialize file transfers in
-  ;; a given direction to/from MACHINE in the presence of several 'offload'
-  ;; hook instance.
-  (when (with-machine-lock machine 'upload
+  (when (begin
           (register-gc-root (derivation-file-name drv) machine)
           (send-files (cons (derivation-file-name drv) inputs)
                       machine))
@@ -412,9 +420,7 @@ MACHINE."
                            #:build-timeout build-timeout)))
       (if (zero? status)
           (begin
-            ;; Likewise (see above.)
-            (with-machine-lock machine 'download
-              (retrieve-files outputs machine))
+            (retrieve-files outputs machine)
             (remove-gc-roots machine)
             (format (current-error-port)
                     "done with offloaded '~a'~%"
@@ -524,10 +530,6 @@ success, #f otherwise."
                (build-requirements-features requirements)
                (build-machine-features machine))))
 
-(define (machine-faster? m1 m2)
-  "Return #t if M1 is faster than M2."
-  (> (build-machine-speed m1) (build-machine-speed m2)))
-
 (define (machine-load machine)
   "Return the load of MACHINE, divided by the number of parallel builds
 allowed on MACHINE."
@@ -535,7 +537,7 @@ allowed on MACHINE."
          (line (read-line pipe)))
     (close-pipe pipe)
     (if (eof-object? line)
-        1.
+        +inf.0    ;MACHINE does not respond, so assume it is infinitely loaded
         (match (string-tokenize line)
           ((one five fifteen . _)
            (let* ((raw        (string->number five))
@@ -546,16 +548,18 @@ allowed on MACHINE."
                      (build-machine-name machine) raw normalized)
              normalized))
           (_
-           1.)))))
+           +inf.0)))))           ;something's fishy about MACHINE, so avoid it
 
-(define (machine-less-loaded? m1 m2)
-  "Return #t if the load on M1 is lower than that on M2."
-  (< (machine-load m1) (machine-load m2)))
+(define (machine-power-factor m)
+  "Return a factor that aggregates the speed and load of M.  The higher the
+better."
+  (/ (build-machine-speed m)
+     (+ 1 (machine-load m))))
 
 (define (machine-less-loaded-or-faster? m1 m2)
-  "Return #t if M1 is either less loaded or faster than M2."
-  (or (machine-less-loaded? m1 m2)
-      (machine-faster? m1 m2)))
+  "Return #t if M1 is either less loaded or faster than M2.  (This relation
+defines a total order on machines.)"
+  (> (machine-power-factor m1) (machine-power-factor m2)))
 
 (define (machine-lock-file machine hint)
   "Return the name of MACHINE's lock file for HINT."
@@ -600,22 +604,25 @@ allowed on MACHINE."
                   (list machine1 slot1)
                   (list machine2 slot2))))))))
 
-    (let ((machines+slots (sort machines+slots
-                                (undecorate machine-less-loaded-or-faster?))))
+    (let loop ((machines+slots
+                (sort machines+slots
+                      (undecorate machine-less-loaded-or-faster?))))
       (match machines+slots
-        (((best slot) (others slots) ...)
-         ;; Release slots from the uninteresting machines.
-         (for-each release-build-slot slots)
-
+        (((best slot) others ...)
          ;; Return the best machine unless it's already overloaded.
          (if (< (machine-load best) 2.)
+             (match others
+               (((machines slots) ...)
+                ;; Release slots from the uninteresting machines.
+                (for-each release-build-slot slots)
+
+                ;; Prevent SLOT from being GC'd.
+                (set! %slots (cons slot %slots))
+                best))
              (begin
-               ;; Prevent SLOT from being GC'd.
-               (set! %slots (cons slot %slots))
-               best)
-             (begin
+               ;; BEST is overloaded, so try the next one.
                (release-build-slot slot)
-               #f)))
+               (loop others))))
         (() #f)))))
 
 (define* (process-request wants-local? system drv features
