@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2014 Nikita Karetnikov <nikita@karetnikov.org>
 ;;;
 ;;; This file is part of GNU Guix.
@@ -175,7 +175,7 @@ to the caller without emitting an error message."
                            %fetch-timeout
                            0)
            (begin
-             (warning (_ "while fetching ~a: server is unresponsive~%")
+             (warning (_ "while fetching ~a: server is somewhat slow~%")
                       (uri->string uri))
              (warning (_ "try `--no-substitutes' if the problem persists~%"))
 
@@ -213,6 +213,15 @@ failure."
                           (cut %make-cache url <...>)
                           '("StoreDir" "WantMassQuery")))))
 
+(define-syntax-rule (open-cache* url)
+  "Delayed variant of 'open-cache' that also lets the user know that they're
+gonna have to wait."
+  (delay (begin
+           (format (current-error-port)
+                   (_ "updating list of substitutes from '~a'...~%")
+                   url)
+           (open-cache url))))
+
 (define-record-type <narinfo>
   (%make-narinfo path uri uri-base compression file-hash file-size nar-hash nar-size
                  references deriver system signature contents)
@@ -241,7 +250,7 @@ failure."
     ((version _ sig)
      (let ((maybe-number (string->number version)))
        (cond ((not (number? maybe-number))
-              (leave (_ "signature version must be a number: ~a~%")
+              (leave (_ "signature version must be a number: ~s~%")
                      version))
              ;; Currently, there are no other versions.
              ((not (= 1 maybe-number))
@@ -313,18 +322,15 @@ No authentication and authorization checks are performed here!"
                      "References" "Deriver" "System"
                      "Signature"))))
 
-(define %signature-line-rx
-  ;; Regexp matching a signature line in a narinfo.
-  (make-regexp "(.+)^[[:blank:]]*Signature:[[:blank:]].+$"))
-
 (define (narinfo-sha256 narinfo)
   "Return the sha256 hash of NARINFO as a bytevector, or #f if NARINFO lacks a
 'Signature' field."
   (let ((contents (narinfo-contents narinfo)))
-    (match (regexp-exec %signature-line-rx contents)
+    (match (string-contains contents "Signature:")
       (#f #f)
-      ((= (cut match:substring <> 1) above-signature)
-       (sha256 (string->utf8 above-signature))))))
+      (index
+       (let ((above-signature (string-take contents index)))
+         (sha256 (string->utf8 above-signature)))))))
 
 (define* (assert-valid-narinfo narinfo
                                #:optional (acl (current-acl))
@@ -671,7 +677,7 @@ substituter disabled~%")
    (with-error-handling                           ; for signature errors
      (match args
        (("--query")
-        (let ((cache (delay (open-cache %cache-url)))
+        (let ((cache (open-cache* %cache-url))
               (acl   (current-acl)))
           (define (valid? obj)
             (and (narinfo? obj) (valid-narinfo? obj acl)))
@@ -722,7 +728,7 @@ substituter disabled~%")
                   (loop (read-line)))))))
        (("--substitute" store-path destination)
         ;; Download STORE-PATH and add store it as a Nar in file DESTINATION.
-        (let* ((cache   (delay (open-cache %cache-url)))
+        (let* ((cache   (open-cache* %cache-url))
                (narinfo (lookup-narinfo cache store-path))
                (uri     (narinfo-uri narinfo)))
           ;; Make sure it is signed and everything.
@@ -758,6 +764,10 @@ substituter disabled~%")
                                             progress)))
             ;; Unpack the Nar at INPUT into DESTINATION.
             (restore-file input destination)
+
+            ;; Skip a line after what 'progress-proc' printed.
+            (newline (current-error-port))
+
             (every (compose zero? cdr waitpid) pids))))
        (("--version")
         (show-version-and-exit "guix substitute-binary"))
