@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -20,6 +20,7 @@
   #:use-module (guix utils)
   #:use-module (guix config)
   #:use-module (guix serialization)
+  #:use-module (guix monads)
   #:autoload   (guix base32) (bytevector->base32-string)
   #:use-module (rnrs bytevectors)
   #:use-module (rnrs io ports)
@@ -94,6 +95,16 @@
 
             register-path
 
+            %store-monad
+            store-bind
+            store-return
+            store-lift
+            store-lower
+            run-with-store
+            %guile-for-build
+            text-file
+            interned-file
+
             %store-prefix
             store-path?
             direct-store-path?
@@ -435,14 +446,14 @@ encoding conversion errors."
 (define* (set-build-options server
                             #:key keep-failed? keep-going? fallback?
                             (verbosity 0)
-                            (max-build-jobs (current-processor-count))
+                            (max-build-jobs 1)
                             timeout
                             (max-silent-time 3600)
                             (use-build-hook? #t)
                             (build-verbosity 0)
                             (log-type 0)
                             (print-build-trace #t)
-                            (build-cores 1)
+                            (build-cores (current-processor-count))
                             (use-substitutes? #t)
                             (binary-caches '())) ; client "untrusted" cache URLs
   ;; Must be called after `open-connection'.
@@ -784,23 +795,25 @@ is raised if the set of paths read from PORT is not signed (as per
       (or done? (loop (process-stderr server port))))
     (= 1 (read-int s))))
 
-(define* (export-paths server paths port #:key (sign? #t))
+(define* (export-paths server paths port #:key (sign? #t) recursive?)
   "Export the store paths listed in PATHS to PORT, in topological order,
-signing them if SIGN? is true."
+signing them if SIGN? is true.  When RECURSIVE? is true, export the closure of
+PATHS---i.e., PATHS and all their dependencies."
   (define ordered
-    ;; Sort PATHS, but don't include their references.
-    (filter (cut member <> paths)
-            (topologically-sorted server paths)))
+    (let ((sorted (topologically-sorted server paths)))
+      ;; When RECURSIVE? is #f, filter out the references of PATHS.
+      (if recursive?
+          sorted
+          (filter (cut member <> paths) sorted))))
 
-  (let ((s (nix-server-socket server)))
-    (let loop ((paths ordered))
-      (match paths
-        (()
-         (write-int 0 port))
-        ((head tail ...)
-         (write-int 1 port)
-         (and (export-path server head port #:sign? sign?)
-              (loop tail)))))))
+  (let loop ((paths ordered))
+    (match paths
+      (()
+       (write-int 0 port))
+      ((head tail ...)
+       (write-int 1 port)
+       (and (export-path server head port #:sign? sign?)
+            (loop tail))))))
 
 (define* (register-path path
                         #:key (references '()) deriver prefix
@@ -834,6 +847,85 @@ be used internally by the daemon's build hook."
       ;; Failed to run %GUIX-REGISTER-PROGRAM.
       #f)))
 
+
+;;;
+;;; Store monad.
+;;;
+
+(define-syntax-rule (define-alias new old)
+  (define-syntax new (identifier-syntax old)))
+
+;; The store monad allows us to (1) build sequences of operations in the
+;; store, and (2) make the store an implicit part of the execution context,
+;; rather than a parameter of every single function.
+(define-alias %store-monad %state-monad)
+(define-alias store-return state-return)
+(define-alias store-bind state-bind)
+
+(define (preserve-documentation original proc)
+  "Return PROC with documentation taken from ORIGINAL."
+  (set-object-property! proc 'documentation
+                        (procedure-property original 'documentation))
+  proc)
+
+(define (store-lift proc)
+  "Lift PROC, a procedure whose first argument is a connection to the store,
+in the store monad."
+  (preserve-documentation proc
+                          (lambda args
+                            (lambda (store)
+                              (values (apply proc store args) store)))))
+
+(define (store-lower proc)
+  "Lower PROC, a monadic procedure in %STORE-MONAD, to a \"normal\" procedure
+taking the store as its first argument."
+  (preserve-documentation proc
+                          (lambda (store . args)
+                            (run-with-store store (apply proc args)))))
+
+;;
+;; Store monad operators.
+;;
+
+(define* (text-file name text)
+  "Return as a monadic value the absolute file name in the store of the file
+containing TEXT, a string."
+  (lambda (store)
+    (values (add-text-to-store store name text '())
+            store)))
+
+(define* (interned-file file #:optional name
+                        #:key (recursive? #t))
+  "Return the name of FILE once interned in the store.  Use NAME as its store
+name, or the basename of FILE if NAME is omitted.
+
+When RECURSIVE? is true, the contents of FILE are added recursively; if FILE
+designates a flat file and RECURSIVE? is true, its contents are added, and its
+permission bits are kept."
+  (lambda (store)
+    (values (add-to-store store (or name (basename file))
+                          recursive? "sha256" file)
+            store)))
+
+(define %guile-for-build
+  ;; The derivation of the Guile to be used within the build environment,
+  ;; when using 'gexp->derivation' and co.
+  (make-parameter #f))
+
+(define* (run-with-store store mval
+                         #:key
+                         (guile-for-build (%guile-for-build))
+                         (system (%current-system)))
+  "Run MVAL, a monadic value in the store monad, in STORE, an open store
+connection, and return the result."
+  (parameterize ((%guile-for-build guile-for-build)
+                 (%current-system system))
+    (call-with-values (lambda ()
+                        (run-with-state mval store))
+      (lambda (result store)
+        ;; Discard the state.
+        result))))
+
 
 ;;;
 ;;; Store paths.
