@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -19,6 +19,7 @@
 (define-module (test-packages)
   #:use-module (guix tests)
   #:use-module (guix store)
+  #:use-module (guix monads)
   #:use-module ((guix utils)
                 ;; Rename the 'location' binding to allow proper syntax
                 ;; matching when setting the 'location' field of a package.
@@ -31,13 +32,17 @@
   #:use-module (guix build-system)
   #:use-module (guix build-system trivial)
   #:use-module (guix build-system gnu)
+  #:use-module (guix profiles)
+  #:use-module (guix scripts package)
   #:use-module (gnu packages)
   #:use-module (gnu packages base)
   #:use-module (gnu packages guile)
   #:use-module (gnu packages bootstrap)
+  #:use-module (gnu packages xml)
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
   #:use-module (srfi srfi-34)
+  #:use-module (srfi srfi-35)
   #:use-module (srfi srfi-64)
   #:use-module (rnrs io ports)
   #:use-module (ice-9 regex)
@@ -48,13 +53,6 @@
 (define %store
   (open-connection-for-tests))
 
-(define-syntax-rule (dummy-package name* extra-fields ...)
-  (package (name name*) (version "0") (source #f)
-           (build-system gnu-build-system)
-           (synopsis #f) (description #f)
-           (home-page #f) (license #f)
-           extra-fields ...))
-
 
 (test-begin "packages")
 
@@ -185,10 +183,10 @@
   (let* ((file   (search-bootstrap-binary "guile-2.0.9.tar.xz"
                                           (%current-system)))
          (sha256 (call-with-input-file file port-sha256))
-         (fetch  (lambda* (store url hash-algo hash
+         (fetch  (lambda* (url hash-algo hash
                            #:optional name #:key system)
                    (pk 'fetch url hash-algo hash name system)
-                   (add-to-store store (basename url) #f "sha256" url)))
+                   (interned-file url)))
          (source (bootstrap-origin
                   (origin
                     (method fetch)
@@ -251,6 +249,36 @@
          (string=? (derivation->output-path drv)
                    (package-output %store package "out")))))
 
+(test-assert "patch not found yields a run-time error"
+  (guard (c ((condition-has-type? c &message)
+             (and (string-contains (condition-message c)
+                                   "does-not-exist.patch")
+                  (string-contains (condition-message c)
+                                   "not found"))))
+    (let ((p (package
+               (inherit (dummy-package "p"))
+               (source (origin
+                         (method (const #f))
+                         (uri "http://whatever")
+                         (patches
+                          (list (search-patch "does-not-exist.patch")))
+                         (sha256
+                          (base32
+                           "0amn0bbwqvsvvsh6drfwz20ydc2czk374lzw5kksbh6bf78k4ks4")))))))
+      (package-derivation %store p)
+      #f)))
+
+(test-assert "reference to non-existent output"
+  ;; See <http://bugs.gnu.org/19630>.
+  (let* ((dep (dummy-package "dep"))
+         (p   (dummy-package "p"
+                (inputs `(("dep" ,dep "non-existent"))))))
+    (guard (c ((derivation-missing-output-error? c)
+               (and (string=? (derivation-missing-output c) "non-existent")
+                    (equal? (package-derivation %store dep)
+                            (derivation-error-derivation c)))))
+      (package-derivation %store p))))
+
 (test-assert "trivial"
   (let* ((p (package (inherit (dummy-package "trivial"))
               (build-system trivial-build-system)
@@ -335,10 +363,10 @@
                            search-paths)))))))
          (x (list (search-path-specification
                    (variable "GUILE_LOAD_PATH")
-                   (directories '("share/guile/site/2.0")))
+                   (files '("share/guile/site/2.0")))
                   (search-path-specification
                    (variable "GUILE_LOAD_COMPILED_PATH")
-                   (directories '("share/guile/site/2.0")))))
+                   (files '("share/guile/site/2.0")))))
          (a (package (inherit (dummy-package "guile"))
               (build-system s)
               (native-search-paths x)))
@@ -534,6 +562,53 @@
     (((? (cut eq? hello <>))) #t)
     (wrong (pk 'find-packages-by-name wrong #f))))
 
+(test-assert "--search-paths with pattern"
+  ;; Make sure 'guix package --search-paths' correctly reports environment
+  ;; variables when file patterns are used (in particular, it must follow
+  ;; symlinks when looking for 'catalog.xml'.)  To do that, we rely on the
+  ;; libxml2 package specification, which contains such a definition.
+  (let* ((p1 (package
+               (name "foo") (version "0") (source #f)
+               (build-system trivial-build-system)
+               (arguments
+                `(#:guile ,%bootstrap-guile
+                  #:modules ((guix build utils))
+                  #:builder (begin
+                              (use-modules (guix build utils))
+                              (let ((out (assoc-ref %outputs "out")))
+                                (mkdir-p (string-append out "/xml/bar/baz"))
+                                (call-with-output-file
+                                    (string-append out "/xml/bar/baz/catalog.xml")
+                                  (lambda (port)
+                                    (display "xml? wat?!" port)))))))
+               (synopsis #f) (description #f)
+               (home-page #f) (license #f)))
+         (p2 (package
+               ;; Provide a fake libxml2 to avoid building the real one.  This
+               ;; is OK because 'guix package' gets search path specifications
+               ;; from the same-named package found in the distro.
+               (name "libxml2") (version "0.0.0") (source #f)
+               (build-system trivial-build-system)
+               (arguments
+                `(#:guile ,%bootstrap-guile
+                  #:builder (mkdir (assoc-ref %outputs "out"))))
+               (native-search-paths (package-native-search-paths libxml2))
+               (synopsis #f) (description #f)
+               (home-page #f) (license #f)))
+         (prof (run-with-store %store
+                 (profile-derivation
+                  (manifest (map package->manifest-entry
+                                 (list p1 p2)))
+                  #:info-dir? #f)
+                 #:guile-for-build (%guile-for-build))))
+    (build-derivations %store (list prof))
+    (string-match (format #f "^export XML_CATALOG_FILES=\"~a/xml/+bar/baz/catalog\\.xml\"\n"
+                          (derivation->output-path prof))
+                  (with-output-to-string
+                    (lambda ()
+                      (guix-package "-p" (derivation->output-path prof)
+                                    "--search-paths"))))))
+
 (test-end "packages")
 
 
